import os
import re

# Dictionary mapping HTML entity names to their corresponding numbers. There are some duplicate entries for variant spellings.
# Compiled by Jack DeLand [howtoreadpoe@gmail.com] from various open source tables scattered across the web. Final code created using pseudocde in ChatGPt. You will find many TODO's in the code. No warranty, express or implied, is provided. Always use on a test copy first. Use entirely at your own risk.
# usage: python html-entities.py

html_entities = {
    # start of heading: "&#1;",
    # start of text: "&#2;",
    # end of text: "&#3;",
    # end of transmission: "&#4;",
    # enquiry: "&#5;",
    # acknowledge: "&#6;",
    # bell: "&#7;",
    # backspace: "&#8;",    
    # "&Tab;": "&#9;",
    # "&NewLine;": "&#10;",    
    # line tabulation: "&#11;",
    # form feed: "&#12;",
    # carriage return: "&#13;",
    # shift out: "&#14;",
    # shift in: "&#15;",
    # data link escape: "&#16;",
    # device control one: "&#17;",
    # device control two: "&#18;",
    # device control three: "&#19;",
    # device control four: "&#20;",
    # negative acknowledge: "&#21;",
    # synchronous idle: "&#22;",
    # end of transmission block: "&#23;",
    # cancel: "&#24;",
    # end of medium: "&#25;",
    # substitute: "&#26;",
    # escape: "&#27;",
    # information separator four: "&#28;",
    # information separator three: "&#29;",
    # information separator two: "&#30;",
    # information separator one: "&#31;",
    # white space: "&#32;",
    "&excl;": "&#33;",
    "&quot;": "&#34;",
    "&QUOT;": "&#34;",
    "&num;": "&#35;",
    "&dollar;": "&#36;",
    "&percnt;": "&#37;",
    "&amp;": "&#38;",
    "&AMP;": "&#38;",
    "&apos;": "&#39;",
    "&lpar;": "&#40;",
    "&rpar;": "&#41;",
    "&midast;": "&#42;",
    "&plus;": "&#43;",
    "&comma;": "&#44;",
    "&hyphen;": "&#45;",
    "&period;": "&#46;",
    "&sol;": "&#47;",
    "&zero;": "&#48;",
    "&one;": "&#49;",
    "&two;": "&#50;",
    "&three;": "&#51;",
    "&four;": "&#52;",
    "&five;": "&#53;",
    "&six;": "&#54;",
    "&seven;": "&#55;",
    "&eight;": "&#56;",
    "&nine;": "&#57;",
    "&colon;": "&#58;",
    "&semi;": "&#59;",
    "&lt;": "&#60;",
    "&LT;": "&#60;",
    "&equals;": "&#61;",
    "&gt;": "&#62;",
    "&GT;": "&#62;",
    "&quest;": "&#63;",
    "&commat;": "&#64;",
    "&A;": "&#65;",
    "&B;": "&#66;",
    "&C;": "&#67;",
    "&D;": "&#68;",
    "&E;": "&#69;",
    "&F;": "&#70;",
    "&G;": "&#71;",
    "&H;": "&#72;",
    "&I;": "&#73;",
    "&J;": "&#74;",
    "&K;": "&#75;",
    "&L;": "&#76;",
    "&M;": "&#77;",
    "&N;": "&#78;",
    "&O;": "&#79;",
    "&P;": "&#80;",
    "&Q;": "&#81;",
    "&R;": "&#82;",
    "&S;": "&#83;",
    "&T;": "&#84;",
    "&U;": "&#85;",
    "&V;": "&#86;",
    "&W;": "&#87;",
    "&X;": "&#88;",
    "&Y;": "&#89;",
    "&Z;": "&#90;",
    "&[;": "&#91;",
    "&lbrack;": "&#91;",
    "&lsqb;": "&#91;",
    "&bsol;": "&#92;",
    "&rbrack;": "&#93;",
    "&rsqb;": "&#93;",
    "&Hat;": "&#94;",
    "&lowbar;": "&#95;",
    "&DiacriticalGrave;": "&#96;",
    "&grave;": "&#96;",
    "&a;": "&#97;",
    "&b;": "&#98;",
    "&c;": "&#99;",
    "&d;": "&#100;",
    "&e;": "&#101;",
    "&f;": "&#102;",
    "&g;": "&#103;",
    "&h;": "&#104;",
    "&i;": "&#105;",
    "&j;": "&#106;",
    "&k;": "&#107;",
    "&l;": "&#108;",
    "&m;": "&#109;",
    "&n;": "&#110;",
    "&o;": "&#111;",
    "&p;": "&#112;",
    "&q;": "&#113;",
    "&r;": "&#114;",
    "&s;": "&#115;",
    "&t;": "&#116;",
    "&u;": "&#117;",
    "&v;": "&#118;",
    "&w;": "&#119;",
    "&x;": "&#120;",
    "&y;": "&#121;",
    "&y;": "&#122;",
    "&lbrace;": "&#123;",
    "&vert;": "&#124;",
    "&VerticalLine;": "&#124;",
    "&rbrace;": "&#125;",
    "&tilde;": "&#126;",
    # DEL: "&#127;",
    "&euro;": "&#128;",
    # undefined [not used in Unicode]: "&#129;",
    "&sbquo;": "&#130;",
    "&fnof;": "&#131;",
    # double low-9 quotation mark: "&#132;",
    # next line (nel): "&#133;",
    # start of selected area: "&#134;",
    # end of selected area: "&#135;",
    # character tabulation set: "&#136;",
    # character tabulation with justification: "&#137;",
    # line tabulation set: "&#138;",
    # partial line forward: "&#139;",
    # partial line backward: "&#140;",
    # reverse line feed: "&#141;",
    # single shift two: "&#142;",
    # single shift three: "&#143;",
    # device control string: "&#144;",
    # private use one: "&#145;",
    # private use two: "&#146;",
    # set transmit state: "&#147;",
    # cancel character: "&#148;",
    # message waiting: "&#149;",
    # start of guarded area: "&#150;",
    # end of guarded area: "&#151;",
    # start of string: "&#152;",
    "&trade;": "&#153;",
    # single character introducer: "&#154;",
    # control sequence introducer: "&#155;",
    # string terminator: "&#156;",
    # operating system command: "&#157;",
    # privacy message: "&#158;",
    # application program command: "&#159;",
    "&NonBreakingSpace;": "&#160;",
    "&nbsp;": "&#160;",    
    "&iexcl;": "&#161;",
    "&cent;": "&#162;",
    "&pound;": "&#163;",
    "&curren;": "&#164;",
    "&yen;": "&#165;",
    "&brvbar;": "&#166;",
    "&sect;": "&#167;",
    "&die;": "&#168;",
    "&copy;": "&#169;",
    "&ordf;": "&#170;",
    "&laquo;": "&#171;",
    "&not;": "&#172;",
    "&shy;": "&#173;",
    "&circledR;": "&#174;",
    "&strns;": "&#175;",
    "&deg;": "&#176;",
    "&pm;": "&#177;",
    "&sup2;": "&#178;",
    "&sup3;": "&#179;",
    "&acute;": "&#180;",
    "&micro;": "&#181;",
    "&para;": "&#182;",
    "&middot;": "&#183;",
    "&cedil;": "&#184;",
    "&sup1;": "&#185;",
    "&ordm;": "&#186;",
    "&raquo;": "&#187;",
    "&frac14;": "&#188;",
    "&half;": "&#189;",
    "&frac34;": "&#190;",
    "&iquest;": "&#191;",
    "&Agrave;": "&#192;",
    "&Aacute;": "&#193;",
    "&Acirc;": "&#194;",
    "&Atilde;": "&#195;",
    "&Auml;": "&#196;",
    "&Aring;": "&#197;",
    "&AElig;": "&#198;",
    "&Ccedil;": "&#199;",
    "&Egrave;": "&#200;",
    "&Eacute;": "&#201;",
    "&Ecirc;": "&#202;",
    "&Euml;": "&#203;",
    "&Igrave;": "&#204;",
    "&Iacute;": "&#205;",
    "&Icirc;": "&#206;",
    "&Iuml;": "&#207;",
    "&ETH;": "&#208;",
    "&Ntilde;": "&#209;",
    "&Ograve;": "&#210;",
    "&Oacute; ": "&#211;",
    "&Ocirc;": "&#212;",
    "&Otilde;": "&#213;",
    "&Ouml;": "&#214;",
    "&times;": "&#215;",
    "&Oslash;": "&#216;",
    "&Ugrave;": "&#217;",
    "&Uacute;": "&#218;",
    "&Ucirc;": "&#219;",
    "&Uuml;": "&#220;",
    "&Yacute;": "&#221;",
    "&Thorn;": "&#222;",
    "&szlig;": "&#223;",
    "&agrave;": "&#224;",
    "&aacute;": "&#225;",
    "&acirc;": "&#226;",
    "&atilde;": "&#227;",
    "&auml;": "&#228;",
    "&aring;": "&#229;",
    "&aelig;": "&#230;",
    "&ccedil;": "&#231;",
    "&egrave;": "&#232;",
    "&eacute;": "&#233;",
    "&ecirc;": "&#234;",
    "&euml;": "&#235;",
    "&igrave;": "&#236;",
    "&iacute;": "&#237;",
    "&icirc;": "&#238;",
    "&iuml;": "&#239;",
    "&eth;": "&#240;",
    "&ntilde;": "&#241;",
    "&ograve;": "&#242;",
    "&oacute;": "&#243;",
    "&ocirc;": "&#244;",
    "&otilde;": "&#245;",
    "&ouml;": "&#246;",
    "&divide;": "&#247;",
    "&oslash;": "&#248;",
    "&ugrave;": "&#249;",
    "&uacute;": "&#250;",
    "&ucirc;": "&#251;",
    "&uuml;": "&#252;",
    "&yacute;": "&#253;",
    "&thorn;": "&#254;",
    "&yuml;": "&#255;",
    "&Amacr;": "&#256;",
    "&amacr;": "&#257;",
    "&Abreve;": "&#258;",
    "&abreve;": "&#259;",
    "&Aogon;": "&#260;",
    "&aogon;": "&#261;",
    "&Cacute;": "&#262;",
    "&cacute;": "&#263;",
    "&Ccirc;": "&#264;",
    "&ccirc;": "&#265;",
    "&Cdot;": "&#266;",
    "&cdot;": "&#267;",
    "&Ccaron;": "&#268;",
    "&ccaron;": "&#269;",
    "&Dcaron;": "&#270;",
    "&dcaron;": "&#271;",
    "&Dstrok;": "&#272;",
    "&dstrok;": "&#273;",
    "&Emacr;": "&#274;",
    "&emacr;": "&#275;",
    # Latin capital letter e with breve: "&#276;",
    # Latin small letter e with breve: "&#277;",    
    "&Edot;": "&#278;",
    "&edot;": "&#279;",
    "&Eogon;": "&#280;",
    "&eogon;": "&#281;",
    "&Ecaron;": "&#282;",
    "&ecaron;": "&#283;",
    "&Gcirc;": "&#284;",
    "&gcirc;": "&#285;",
    "&Gbreve;": "&#286;",
    "&gbreve;": "&#287;",
    "&Gdot;": "&#288;",
    "&gdot;": "&#289;",
    "&Gcedil;": "&#290;",
    "&Oacute;": "&#291;",
    "&oacute;": "&#291;",
    "&Hcirc;": "&#292;",
    "&hcirc;": "&#293;",
    "&Hstrok;": "&#294;",
    "&hstrok;": "&#295;",
    "&Itilde;": "&#296;",
    "&itilde;": "&#297;",
    "&Imacr;": "&#298;",
    "&imacr;": "&#299;",
    "&Ibreve;": "&#300;",
    "&ibreve;": "&#301;",
    "&Iogon;": "&#302;",
    "&iogon;": "&#303;",
    "&Idot;": "&#304;",
    "&imath;": "&#305;",
    "&inodot;": "&#305;",
    "&IJlig;": "&#306;",
    "&ijlig;": "&#307;",
    "&Jcirc;": "&#308;",
    "&jcirc;": "&#309;",
    "&Kcedil;": "&#310;",
    "&kcedil;": "&#311;",
    "&kgreen;": "&#312;",
    "&Lacute;": "&#313;",
    "&lacute;": "&#314;",
    "&Lcedil;": "&#315;",
    "&lcedil;": "&#316;",
    "&Lcaron;": "&#317;",
    "&lcaron;": "&#318;",
    "&Lmidot;": "&#319;",
    "&lmidot;": "&#320;",
    "&Lstrok;": "&#321;",
    "&lstrok;": "&#322;",
    "&Nacute;": "&#323;",
    "&nacute;": "&#324;",
    "&Ncedil;": "&#325;",
    "&ncedil;": "&#326;",
    "&Ncaron;": "&#327;",
    "&ncaron;": "&#328;",
    "&napos;": "&#329;",
    "&ENG;": "&#330;",
    "&eng;": "&#331;",
    "&Omacr;": "&#332;",
    "&omacr;": "&#333;",
    # Latin capital letter o with breve: "&#334;",   
    # Latin small letter o with breve: "&#335;",   
    "&Odblac;": "&#336;",
    "&odblac;": "&#337;",
    "&OElig;": "&#338;",
    "&oelig;": "&#339;",
    "&Racute;": "&#340;",
    "&racute;": "&#341;",
    "&Rcedil;": "&#342;",
    "&rcedil;": "&#343;",
    "&Rcaron;": "&#344;",
    "&rcaron;": "&#345;",
    "&Sacute;": "&#346;",
    "&sacute;": "&#347;",
    "&Scirc;": "&#348;",
    "&scirc;": "&#349;",
    "&Scedil;": "&#350;",
    "&scedil;": "&#351;",
    "&Scaron;": "&#352;",
    "&scaron;": "&#353;",
    "&Tcedil;": "&#354;",
    "&tcedil;": "&#355;",
    "&Tcaron;": "&#356;",
    "&tcaron;": "&#357;",
    "&Tstrok;": "&#358;",
    "&tstrok;": "&#359;",
    "&Utilde;": "&#360;",
    "&utilde;": "&#361;",
    "&Umacr;": "&#362;",
    "&umacr;": "&#363;",
    "&Ubreve;": "&#364;",
    "&ubreve;": "&#365;",
    "&Uring;": "&#366;",
    "&uring;": "&#367;",
    "&Udblac;": "&#368;",
    "&udblac;": "&#369;",
    "&Uogon;": "&#370;",
    "&uogon;": "&#371;",
    "&Wcirc;": "&#372;",
    "&wcirc;": "&#373;",
    "&Ycirc;": "&#374;",
    "&ycirc;": "&#375;",
    "&Yuml;": "&#376;",
    "&Zacute;": "&#377;",
    "&zacute;": "&#378;",
    "&Zdot;": "&#379;",
    "&zdot;": "&#380;",
    "&Zcaron;": "&#381;",
    "&zcaron;": "&#382;",
    "&longs;": "&#383;",
    # Latin small letter B with stroke: "&#384;",
    # Latin capital letter H with stroke (U+0181): "&#385;",
    # Latin capital letter I with stroke (U+0182): "&#386;",
    # Latin small letter I with stroke (U+0183): "&#387;",
    # Latin small letter J with stroke (U+0184): "&#388;",
    # capital letter U with diaeresis and macron: "&#389;",
    # Latin small letter U with diaeresis and macron: "&#390;",
    # Latin capital letter U with diaeresis and Acute: "&#391;",
    # Latin small letter U with diaeresis and Acute: "&#392;",
    # Latin capital letter Delta with stroke: "&#393;",
    # Latin capital letter D with hook: "&#394;",
    # Latin capital letter D with Topbar: "&#395;",
    # Latin small letter D with Topbar: "&#396;",
    # Latin small letter Turned Delta: "&#397;",
    # Latin capital letter Reversed E: "&#398;",
    # Latin capital letter Schwa: "&#399;",
    # Latin capital letter Open E: "&#400;",
    # Latin capital letter F with hook: "&#401;",
    "&fnof;": "&#402;",
    # Latin capital letter B with hook: "&#403;",
    # Latin capital letter B with topbar: "&#404;",
    # Latin small letter b with topbar: "&#405;",
    # Latin capital letter open O: "&#406;",
    # Latin capital letter C with hook: "&#407;",
    # Latin small letter c with hook: "&#408;",
    # Latin capital letter African D: "&#409;",
    # Latin capital letter D with hook: "&#410;",
    # Latin small letter B With Topbar: "&#411;",
    # Latin capital letter Tone Six: "&#412;",
    # Latin small letter Tone Six: "&#413;",
    # Latin capital letter Open O: "&#414;",
    # Latin capital letter African D: "&#415;",
    # Latin small letter African D: "&#416;",
    # Latin capital letter D With hook: "&#417;",
    # Latin capital letter African D With hook: "&#418;",
    # Latin capital letter African D With Topbar: "&#419;",
    # Latin capital letter P with hook: "&#420;",
    # Latin small letter P with hook: "&#421;",
    # Latin letter Y with stroke: "&#422;",
    # Latin capital letter Tone two: "&#423;",
    # Latin small letter Tone two: "&#424;",
    # Latin capital letter ESH: "&#425;",
    # Latin letter reversed ESH loop: "&#426;",
    # Latin small letter T with palatal hook: "&#427;",
    # Latin capital letter T with hook: "&#428;",
    # Latin small letter T with hook: "&#429;",
    # Latin capital letter T with retroflex hook: "&#430;",
    # Latin capital letter U with horn: "&#431;",
    # Latin small letter U with horn: "&#432;",
    # Latin capital letter upsilon: "&#433;",
    # Latin capital letter V with hook: "&#434;",
    # Latin capital letter Y with hook: "&#435;",
    # Latin small letter Y with hook: "&#436;",
    "&imped;": "&#437;",
    # Latin small letter Z: "&#438;",   
    # Latin capital letter ezh: "&#439;",  
    # Latin capital letter ezh reversed: "&#440;",  
    # Latin small letter ezh reversed: "&#441;", 
    # Latin small letter ezh with tail: "&#442;", 
    # Latin letter two with stroke: "&#443;", 
    # Latin capital letter tone five: "&#444;", 
    # Latin small letter tone five: "&#445;", 
    # Latin letter inverted glottal stop with stroke: "&#446;", 
    # Latin letter wynn: "&#447;", 
    # Latin letter dental click: "&#448;", 
    # Latin letter lateral click: "&#449;", 
    # Latin letter alveolar click: "&#450;", 
    # Latin letter retroflex click: "&#451;", 
    # Latin capital letter dz with caron: "&#452;", 
    # Latin capital letter d with small letter z with caron: "&#453;", 
    # Latin small letter dz with caron: "&#454;", 
    # Latin capital letter lj: "&#455;", 
    # Latin capital letter l with small letter j: "&#456;",
    # Latin small letter lj: "&#457;", 
    # Latin capital letter nj: "&#458;", 
    # Latin capital letter n with small letter j: "&#459;", 
    # Latin small letter nj: "&#460;", 
    # Latin capital letter a with caron: "&#461;", 
    # Latin small letter a with caron: "&#462;", 
    # Latin capital letter i with caron: "&#463;", 
    # Latin small letter i with caron: "&#464;",
    # Latin capital letter o with caron: "&#465;", 
    # Latin small letter o with caron: "&#466;", 
    # Latin capital letter u with caron: "&#467;", 
    # Latin small letter u with caron: "&#468;", 
    # Latin capital letter u with diaeresis and macron: "&#469;", 
    # Latin small letter u with diaeresis and macron: "&#470;", 
    # Latin capital letter u with diaeresis and acute: "&#471;", 
    # Latin small letter u with diaeresis and acute: "&#472;", 
    # Latin capital letter u with diaeresis and caron: "&#473;", 
    # Latin small letter u with diaeresis and caron: "&#474;", 
    # Latin capital letter u with diaeresis and grave: "&#475;", 
    # Latin small letter u with diaeresis and grave: "&#476;",
    # Latin small letter turned e: "&#477;", 
    # Latin capital letter a with diaeresis and macron: "&#478;", 
    # Latin small letter a with diaeresis and macron: "&#479;", 
    # Latin capital letter a with dot above and macron: "&#480;", 
    # Latin small letter a with dot above and macron: "&#481;", 
    # Latin capital letter ae with macron: "&#482;", 
    # Latin small letter ae with macron: "&#483;", 
    # Latin capital letter g with stroke: "&#484;", 
    # Latin small letter g with stroke: "&#485;", 
    # Latin capital letter g with caron: "&#486;",
    # Latin small letter g with caron: "&#487;", 
    # Latin capital letter k with caron: "&#488;", 
    # Latin small letter k with caron: "&#489;", 
    # Latin capital letter o with ogonek: "&#490;",
    # Latin small letter o with ogonek: "&#491;", 
    # Latin capital letter o with ogonek and macron: "&#492;", 
    # Latin small letter o with ogonek and macron: "&#493;", 
    # Latin capital letter ezh with caron: "&#494;", 
    # Latin small letter ezh with caron: "&#495;", 
    # Latin small letter j with caron: "&#496;",
    # Latin capital letter dz: "&#497;", 
    # Latin capital letter d with small letter z: "&#498;", 
    # Latin small letter dz: "&#499;", 
    # Latin capital letter g with acute: "&#500;",
    "&gacute;": "&#501;",
    # 502-566: TODO    
    "&jmath;": "&#567;",
    # 568-709: TODO  
    "&circ;": "&#710;",
    "&Hacek;": "&#711;",
    # 712-727: TODO 
    "&breve;": "&#728;",
    "&dot;": "&#729;",
    "&ring;": "&#730;",
    "&ogon;": "&#731;",
    "&DiacriticalTilde;": "&#732;",
    "&DiacriticalDoubleAcute;": "&#733;",
    # 734-784: TODO     
    "&DownBreve;": "&#785;",
    # 786-817: TODO  
    "&UnderBar;": "&#818;",
    # 819-912: TODO      
    "&Alpha;": "&#913;",
    "&Beta;": "&#914;",
    "&Gamma;": "&#915;",
    "&Delta;": "&#916;",
    "&Epsilon;": "&#917;",
    "&Zeta;": "&#918;",
    "&Eta;": "&#919;",
    "&Theta;": "&#920;",
    "&Iota;": "&#921;",
    "&Kappa;": "&#922;",
    "&Lambda;": "&#923;",
    "&Mu;": "&#924;",
    "&Nu;": "&#925;",
    "&Xi;": "&#926;",
    "&Omicron;": "&#927;",
    "&Pi;": "&#928;",
    "&Rho;": "&#929;",
    "&Rho;": "&#930;",
    "&Sigma;": "&#931;",
    "&Tau;": "&#932;",
    "&Upsilon;": "&#933;",
    "&Phi;": "&#934;",
    "&Chi;": "&#935;",
    "&Psi;": "&#936;",
    "&Omega;": "&#937;",
    # Greek capital letter iota with dialytika: "&#938;",    
    # Greek capital letter upsilon with dialytika: "&#939;",    
    # Greek small letter alpha with tonos: "&#940;",
    # Greek small letter epsilon with tonos: "&#941;",
    # Greek small letter eta with tonos: "&#942;",    
    # Greek small letter iota with tonos: "&#943;",    
    # Greek small letter upsilon with dialytika and tonos: "&#944;", 
    "&alpha;": "&#945;",
    "&beta;": "&#946;",
    "&gamma;": "&#947;",
    "&delta;": "&#948;",
    "&varepsilon;": "&#949;",
    "&epsilon;": "&#949;",    
    "&zeta;": "&#950;",
    "&eta;": "&#951;",
    "&theta;": "&#952;",
    "&iota;": "&#953;",
    "&kappa;": "&#954;",
    "&lambda;": "&#955;",
    "&mu;": "&#956;",
    "&nu;": "&#957;",
    "&xi;": "&#958;",
    "&omicron;": "&#959;",
    "&pi;": "&#960;",
    "&rho;": "&#961;",
    "&sigmaf;": "&#962;",
    "&sigmav;": "&#962;",
    "&varsigma;": "&#962;",
    "&sigma;": "&#963;",
    "&tau;": "&#964;",
    "&upsi;": "&#965;",
    "&upsilon;": "&#965;",
    "&phi;": "&#966;",
    "&phiv;": "&#966;",
    "&varphi;": "&#966;",
    "&chi;": "&#967;",
    "&psi;": "&#968;",
    "&omega;": "&#969;",
    # Greek small letter iota with dialytika: "&#970;",    
    # Greek small letter upsilon with dialytika: "&#971;",    
    # Greek small letter omicron with tonos: "&#972;",   
    # Greek small letter upsilon with tonos: "&#973;",    
    # Greek small letter omega with tonos: "&#974;",    
    # Greek capital kai symbol: "&#975;",    
    # Greek beta symbol: "&#976;",   
    "&thetasym;": "&#977;",
    "&thetav;": "&#977;",
    "&vartheta;": "&#977;",
    "&Upsi;": "&#978;",
    "&upsih;": "&#978;",
    # Greek upsilon with acute and hook symbol: "&#979;",  
    # Greek upsilon with diaeresis and hook symbol: "&#980;",    
    "&straightphi;": "&#981;",
    "&piv;": "&#982;",
    "&varpi;": "&#982;",
    # Greek kai symbol: "&#983;",    
    # Greek letter archaic koppa: "&#984;",   
    # Greek small letter archaic koppa: "&#985;",    
    # Greek letter stigma: "&#986;",    
    # Greek small letter stigma: "&#987;",    
    "&Gammad;": "&#988;",
    "&digamma;": "&#989;",
    "&gammad;": "&#989;",
    # Greek letter koppa: "&#990;",    
    # Greek small letter koppa: "&#991;",   
    # Greek letter sampi: "&#992;",    
    # Greek small letter sampi: "&#993;",    
    # Coptic capital letter shei: "&#994;",      
    # Coptic small letter shei: "&#995;",    
    # Coptic capital letter fei: "&#996;",   
    # Coptic small letter fei: "&#997;",    
    # Coptic capital letter khei: "&#998;",    
    # Coptic small letter khei: "&#999;",     
    "&kappav;": "&#1000;",
    "&varrho;": "&#1001;",
    "&epsi;": "&#1002;",
    "&bepsi;": "&#1003;",
    "&IOcy;": "&#1004;",
    "&DJcy;": "&#1005;",    
    "&bepsi;": "&#1006;",
    "&IOcy;": "&#1007;",   
    "&kappav;": "&#1008;",
    "&varrho;": "&#1009;",
    # Greek lunate sigma symbol: "&#1010;",    
    # Greek letter yot: "&#1011;",   
    # Greek capital theta symbol: "&#1012;",  
    "&epsi;": "&#1013;",
    "&bepsi;": "&#1014;",
    # Greek capital letter sho: "&#1015;",    
    # Greek small letter sho: "&#1016;",   
    # Greek capital lunate sigma symbol: "&#1017;",    
    # Greek capital letter san: "&#1018;",    
    # Greek small letter san: "&#1019;",   
    # Greek rho with stroke symbol: "&#1020;",   
    # Greek capital reversed lunate sigma symbol: "&#1021;",    
    # Greek capital dotted lunate sigma symbol: "&#1022;",   
    # Greek capital reversed dotted lunate sigma symbol: "&#1023;",    
    # Cyrillic capital letter ie with grave: "&#1024;",     
    "&IOcy;": "&#1025;",
    "&DJcy;": "&#1026;",
    "&GJcy;": "&#1027;",
    "&Jukcy;": "&#1028;",
    "&DScy;": "&#1029;",
    "&Iukcy;": "&#1030;",
    "&YIcy;": "&#1031;",
    "&Jsercy;": "&#1032;",
    "&LJcy;": "&#1033;",
    "&NJcy;": "&#1034;",
    "&TSHcy;": "&#1035;",
    "&KJcy;": "&#1036;",
    # Cyrillic capital letter I with grave: "&#1037;",
    "&Ubrcy;": "&#1038;",
    "&DZcy;": "&#1039;",
    "&Acy;": "&#1040;",
    "&Bcy;": "&#1041;",
    "&Vcy;": "&#1042;",
    "&Gcy;": "&#1043;",
    "&Dcy;": "&#1044;",
    "&IEcy;": "&#1045;",
    "&ZHcy;": "&#1046;",
    "&Zcy;": "&#1047;",
    "&Icy;": "&#1048;",
    "&Jcy;": "&#1049;",
    "&Kcy;": "&#1050;",
    "&Lcy;": "&#1051;",
    "&Mcy;": "&#1052;",
    "&Ncy;": "&#1053;",
    "&Ocy;": "&#1054;",
    "&Pcy;": "&#1055;",
    "&Rcy;": "&#1056;",
    "&Scy;": "&#1057;",
    "&Tcy;": "&#1058;",
    "&Ucy;": "&#1059;",
    "&Fcy;": "&#1060;",
    "&KHcy;": "&#1061;",
    "&TScy;": "&#1062;",
    "&CHcy;": "&#1063;",
    "&SHcy;": "&#1064;",
    "&SHCHcy;": "&#1065;",
    "&HARDcy;": "&#1066;",
    "&Ycy;": "&#1067;",
    "&SOFTcy;": "&#1068;",
    "&Ecy;": "&#1069;",
    "&YUcy;": "&#1070;",
    "&YAcy;": "&#1071;",
    "&acy;": "&#1072;",
    "&bcy;": "&#1073;",
    "&vcy;": "&#1074;",
    "&gcy;": "&#1075;",
    "&dcy;": "&#1076;",
    "&iecy;": "&#1077;",
    "&zhcy;": "&#1078;",
    "&zcy;": "&#1079;",
    "&icy;": "&#1080;",
    "&jcy;": "&#1081;",
    "&kcy;": "&#1082;",
    "&lcy;": "&#1083;",
    "&mcy;": "&#1084;",
    "&ncy;": "&#1085;",
    "&ocy;": "&#1086;",
    "&pcy;": "&#1087;",
    "&rcy;": "&#1088;",
    "&scy;": "&#1089;",
    "&tcy;": "&#1090;",
    "&ucy;": "&#1091;",
    "&fcy;": "&#1092;",
    "&khcy;": "&#1093;",
    "&tscy;": "&#1094;",
    "&chcy;": "&#1095;",
    "&shcy;": "&#1096;",
    "&shchcy;": "&#1097;",
    "&hardcy;": "&#1098;",
    "&ycy;": "&#1099;",
    "&softcy;": "&#1100;",
    "&ecy;": "&#1101;",
    "&yucy;": "&#1102;",
    "&yacy;": "&#1103;",
    # Cyrillic small letter ie with grave: "&#1104;",   
    "&iocy;": "&#1105;",
    "&djcy;": "&#1106;",
    "&gjcy;": "&#1107;",
    "&jukcy;": "&#1108;",
    "&dscy;": "&#1109;",
    "&iukcy;": "&#1110;",
    "&yicy;": "&#1111;",
    "&jsercy;": "&#1112;",
    "&ljcy;": "&#1113;",
    "&njcy;": "&#1114;",
    "&tshcy;": "&#1115;",
    "&kjcy;": "&#1116;",
    # Cyrillic small letter i with grave: "&#1117;",
    "&ubrcy;": "&#1118;",
    "&dzcy;": "&#1119;",
    # 1120-8193:: TODO     
    "&ensp;": "&#8194;",
    "&emsp;": "&#8195;",
    "&emsp13;": "&#8196;",
    "&emsp14;": "&#8197;",
    # "six-per-em space: "&#8198;",    
    "&numsp;": "&#8199;",
    "&puncsp;": "&#8200;",
    "&thinsp;": "&#8201;",
    "&VeryThinSpace;": "&#8202;",
    "&NegativeMediumSpace;": "&#8203;",
    "&NegativeThickSpace;": "&#8203;",
    "&NegativeThinSpace;": "&#8203;",
    "&NegativeVeryThinSpace;": "&#8203;",
    "&ZeroWidthSpace;": "&#8203;",
    "&zwnj;": "&#8204;",
    "&zwj;": "&#8205;",
    "&lrm;": "&#8206;",
    "&rlm;": "&#8207;",
    "&dash;": "&#8208;",
    # non-breaking hyphen: "&#8209;",   
    # figure dash: "&#8210;",     
    "&ndash;": "&#8211;",
    "&mdash;": "&#8212;",
    "&horbar;": "&#8213;",
    "&Verbar;": "&#8214;",
    # double low line: "&#8215;",    
    "&OpenCurlyQuote;": "&#8216;",
    "&CloseCurlyQuote;": "&#8217;",
    "&rsquo;": "&#8217;",
    "&sbquo;": "&#8218;",
    # single high-reversed-9 quotation mark: "&#8219;",   
    "&ldquo;": "&#8220;",
    "&OpenCurlyDoubleQuote;": "&#8220;",
    "&CloseCurlyDoubleQuote;": "&#8221;",
    "&rdquo;": "&#8221;",
    "&ldquor;": "&#8222;",
    # double high-reversed-9 quotation mark: "&#8223;",    
    "&dagger;": "&#8224;",
    "&Dagger;": "&#8225;",
    "&ddagger;": "&#8225;",
    "&bull;": "&#8226;",
    "&bullet;": "&#8226;",
    # triangular bullet: "&#8227;",    
    # one dot leader: "&#8228;",
    "&nldr;": "&#8229;",
    "&hellip;": "&#8230;",
    "&mldr;": "&#8230;",
    # 8231-8239 TODO
    "&permil;": "&#8240;",
    "&pertenk;": "&#8241;",
    "&prime;": "&#8242;",
    "&Prime;": "&#8243;",
    "&tprime;": "&#8244;",
    "&backprime;": "&#8245;",
    # reversed double prime: "&#8246;",
    # reversed triple prime: "&#8247;",
    # caret: "&#8248;",
    "&bprime;": "&#8245;",
    "&lsaquo;": "&#8249;",
    "&rsaquo;": "&#8250;",
    # reference mark: "&#8251;",
    # double exclamation mark: "&#8252;",
    # [not found]: "&#8253;",
    "&oline;": "&#8254;",
    # undertie: "&#8255;",
    # character tie: "&#8256;",
    "&caret;": "&#8257;",   
    # asterism: "&#8258;",    
    "&hybull;": "&#8259;",
    "&frasl;": "&#8260;",
    # 8261-8270: TODO      
    "&bsemi;": "&#8271;",
    # 8272-8278: TODO 
    "&qprime;": "&#8279;",
    # 8280-8286: TODO     
    "&MediumSpace;": "&#8287;",
    "&NoBreak;": "&#8288;",
    "&af;": "&#8289;",
    "&ApplyFunction;": "&#8289;",
    "&InvisibleTimes;": "&#8290;",
    "&it;": "&#8290;",
    "&ic;": "&#8291;",
    "&InvisibleComma;": "&#8291;",
    # 8292-8363: TODO    
    "&euro;": "&#8364;",
    # 8365-8410: TODO
    "&tdot;": "&#8411;",
    "&TripleDot;": "&#8411;",
    "&DotDot;": "&#8412;",
    # 8413-8449: TODO   
    "&complexes;": "&#8450;",
    "&Copf;": "&#8450;",
    # degree Celsius: "&#8451;",    
    # center line symbol: "&#8452;",    
    "&incare;": "&#8453;",
    # cada una: "&#8454;",    
    # euler constant: "&#8455;",    
    # scruple: "&#8456;",   
    # degree Fahrenheit: "&#8457;",    
    "&gscr;": "&#8458;",
    "&hamilt;": "&#8459;",
    "&HilbertSpace;": "&#8459;",
    "&Hscr;": "&#8459;",
    "&Hfr;": "&#8460;",
    "&Poincareplane;": "&#8460;",
    "&quaternions;": "&#8461;",
    "&Hopf;": "&#8461;",
    "&planckh;": "&#8462;",
    "&hbar;": "&#8463;",
    "&plankv;": "&#8463;",
    "&hslash;": "&#8463;",
    "&Iscr;": "&#8464;",
    "&imagline;": "&#8464;",
    "&image;": "&#8465;",
    "&Im;": "&#8465;",
    "&imagpart;": "&#8465;",
    "&Ifr;": "&#8465;",
    "&Lscr;": "&#8466;",
    "&lagran;": "&#8466;",
    "&Laplacetrf;": "&#8466;",
    # script small l: "&#8467;",
    # l b bar symbol: "&#8468;",    
    "&Nopf;": "&#8469;",
    "&naturals;": "&#8469;",
    "&numero;": "&#8470;",
    "&copysr;": "&#8471;",
    "&weierp;": "&#8472;",
    "&wp;": "&#8472;",
    "&Popf;": "&#8473;",
    "&primes;": "&#8473;",
    "&rationals;": "&#8474;",
    "&Qopf;": "&#8474;",
    "&Rscr;": "&#8475;",
    "&realine;": "&#8475;",
    "&real;": "&#8476;",
    "&Re;": "&#8476;",
    "&Rfr;": "&#8476;",
    "&reals;": "&#8477;",
    "&Ropf;": "&#8477;",
    "&rx;": "&#8478;",
    # response: "&#8479;",
    # service mark: "&#8480;",
    # telephone sign: "&#8481;",
    "&trade;": "&#8482;",
    "&TRADE;": "&#8482;",
    "&versicle;": "&#8483;",
    "&integers;": "&#8484;",
    "&Zopf;": "&#8484;",
    # ounce sign: "&#8485;",
    "&ohm;": "&#8486;",
    "&mho;": "&#8487;",
    "&Zfr;": "&#8488;",
    "&zeetrf;": "&#8488;",
    "&iiota;": "&#8489;",
    # Kelvin sign: "&#8490;",       
    "&angst;": "&#8491;",
    "&bernou;": "&#8492;",
    "&Bernoullis;": "&#8492;",
    "&Bscr;": "&#8492;",
    "&Cfr;": "&#8493;",
    "&Cayleys;": "&#8493;",
    # estimated symbol: "&#8494;",
    "&escr;": "&#8495;",
    "&Escr;": "&#8496;",
    "&expectation;": "&#8496;",
    "&Fscr;": "&#8497;",
    "&Fouriertrf;": "&#8497;",
    # turned capital f: "&#8498;", 
    "&phmmat;": "&#8499;",
    "&Mellintrf;": "&#8499;",
    "&Mscr;": "&#8499;",
    "&order;": "&#8500;",
    "&orderof;": "&#8500;",
    "&oscr;": "&#8500;",
    "&alefsym;": "&#8501;",
    "&aleph;": "&#8501;",
    "&beth;": "&#8502;",
    "&gimel;": "&#8503;",
    "&daleth;": "&#8504;",
    # information source: "&#8505;",
    # rotated capital q: "&#8506;",
    # facsimile sign: "&#8507;",
    # double-struck small pi: "&#8508;",
    # double-struck small gamma: "&#8509;",
    # double-struck capital gamma: "&#8510;",
    # double-struck capital pi: "&#8511;",
    # double-struck n-ary summation: "&#8512;",
    # turned sans-serif capital g: "&#8513;",
    # turned sans-serif capital l: "&#8514;",
    # reversed sans-serif capital l: "&#8515;",
    # turned sans-serif capital y: "&#8516;",
    "&CapitalDifferentialD;": "&#8517;",
    "&DD;": "&#8517;",
    "&DifferentialD;": "&#8518;",
    "&dd;": "&#8518;",
    "&ExponentialE;": "&#8519;",
    "&exponentiale;": "&#8519;",
    "&ee;": "&#8519;",
    "&ImaginaryI;": "&#8520;",
    "&ii;": "&#8520;",
    # double-struck italic small j: "&#8521;",
    # property line: "&#8522;",
    # turned ampersand: "&#8523;",
    # per sign: "&#8524;",
    # aktieselskab: "&#8525;",
    # turned small f: "&#8526;",
    # symbol for samaritan source: "&#8527;",
    # vulgar fraction one seventh: "&#8528;",
    # vulgar fraction one ninth: "&#8529;",
    # vulgar fraction one tenth: "&#8530;",
    # vulgar fraction one third: "&#8531;",
    # vulgar fraction two thirds: "&#8532;",
    # vulgar fraction one fifth: "&#8533;",
    # vulgar fraction two fifths: "&#8534;",
    # vulgar fraction three fifths: "&#8535;",
    # vulgar fraction four fifths: "&#8536;",
    # vulgar fraction one sixth: "&#8537;",
    # vulgar fraction five sixths: "&#8538;",
    # vulgar fraction one eighth: "&#8539;",
    # vulgar fraction three eighths: "&#8540;",
    # vulgar fraction five eighths: "&#8541;",
    # vulgar fraction seven eighths: "&#8542;",
    # fraction numerator one: "&#8543;",
    # Roman numeral one: "&#8544;",
    # Roman numeral two: "&#8545;",
    # Roman numeral three: "&#8546;",
    # Roman numeral four: "&#8547;",
    # Roman numeral five: "&#8548;",
    # Roman numeral six: "&#8549;",
    # Roman numeral seven: "&#8550;",
    # Roman numeral eight: "&#8551;",
    # Roman numeral nine: "&#8552;",
    # Roman numeral ten: "&#8553;",
    # Roman numeral eleven: "&#8554;",
    # Roman numeral twelve: "&#8555;",
    # Roman numeral fifty: "&#8556;",
    # Roman numeral one hundred: "&#8557;",
    # Roman numeral five hundred: "&#8558;",
    # Roman numeral one thousand: "&#8559;",
    # small Roman numeral one: "&#8560;",
    # small Roman numeral two: "&#8561;",
    # small Roman numeral three: "&#8562;",
    # small Roman numeral four: "&#8563;",
    # small Roman numeral five: "&#8564;",
    # small Roman numeral six: "&#8565;",
    # small Roman numeral seven: "&#8566;",
    # small Roman numeral eight: "&#8567;",
    # small Roman numeral nine: "&#8568;",
    # small Roman numeral ten: "&#8569;",
    # small Roman numeral eleven: "&#8570;",
    # small Roman numeral twelve: "&#8571;",
    # small Roman numeral fifty: "&#8572;",
    # small Roman numeral one hundred: "&#8573;",
    # small Roman numeral five hundred: "&#8574;",
    # small Roman numeral one thousand: "&#8575;",
    # Roman numeral one thousand c d: "&#8576;",
    # Roman numeral five thousand: "&#8577;",
    # Roman numeral ten thousand: "&#8578;",
    # Roman numeral reversed one hundred: "&#8579;",
    # Latin small letter reversed c: "&#8580;",
    # Roman numeral six late form: "&#8581;",
    # Roman numeral fifty early form: "&#8582;",
    # Roman numeral fifty thousand: "&#8583;",
    # Roman numeral one hundred thousand: "&#8584;",
    # vulgar fraction zero thirds: "&#8585;",
    # turned digit two: "&#8586;",
    # turned digit three: "&#8587;",
    # [undefined character]: "&#8588;",
    # [undefined character]: "&#8589;",
    # [undefined character]: "&#8590;",   
    # [undefined character]: "&#8591;",
    "&larr;": "&#8592;",
    "&leftarrow;": "&#8592;",
    "&slarr;": "&#8592;",
    "&LeftArrow;": "&#8592;",
    "&ShortLeftArrow;": "&#8592;",
    "&uarr;": "&#8593;",
    "&uparrow;": "&#8593;",
    "&UpArrow;": "&#8593;",
    "&ShortUpArrow;": "&#8593;",
    "&rarr;": "&#8594;",
    "&rightarrow;": "&#8594;",
    "&RightArrow;": "&#8594;",
    "&srarr;": "&#8594;",
    "&ShortRightArrow;": "&#8594;",
    "&darr;": "&#8595;",
    "&downarrow;": "&#8595;",
    "&DownArrow;": "&#8595;",
    "&ShortDownArrow;": "&#8595;",
    "&harr;": "&#8596;",
    "&leftrightarrow;": "&#8596;",
    "&LeftRightArrow;": "&#8596;",
    "&varr;": "&#8597;",
    "&updownarrow;": "&#8597;",
    "&UpDownArrow;": "&#8597;",
    "&nwarr;": "&#8598;",
    "&UpperLeftArrow;": "&#8598;",
    "&nwarrow;": "&#8598;",
    "&nearr;": "&#8599;",
    "&UpperRightArrow;": "&#8599;",
    "&nearrow;": "&#8599;",
    "&searr;": "&#8600;",
    "&searrow;": "&#8600;",
    "&LowerRightArrow;": "&#8600;",
    "&swarr;": "&#8601;",
    "&swarrow;": "&#8601;",
    "&LowerLeftArrow;": "&#8601;",
    "&nlarr;": "&#8602;",
    "&nleftarrow;": "&#8602;",
    "&nrarr;": "&#8603;",
    "&nrightarrow;": "&#8603;",
    # leftwards wave arrow": "&#8604;",     
    "&rarrw;": "&#8605;",
    "&rightsquigarrow;": "&#8605;",
    "&Larr;": "&#8606;",
    "&twoheadleftarrow;": "&#8606;",
    "&Uarr;": "&#8607;",
    "&Rarr;": "&#8608;",
    "&twoheadrightarrow;": "&#8608;",
    "&Darr;": "&#8609;",
    "&larrtl;": "&#8610;",
    "&leftarrowtail;": "&#8610;",
    "&rarrtl;": "&#8611;",
    "&rightarrowtail;": "&#8611;",
    "&LeftTeeArrow;": "&#8612;",
    "&mapstoleft;": "&#8612;",
    "&UpTeeArrow;": "&#8613;",
    "&mapstoup;": "&#8613;",
    "&map;": "&#8614;",
    "&RightTeeArrow;": "&#8614;",
    "&mapsto;": "&#8614;",
    "&DownTeeArrow;": "&#8615;",
    # up down arrow with base: "&#8616;",
    "&larrhk;": "&#8617;",
    "&hookleftarrow;": "&#8617;",
    "&rarrhk;": "&#8618;",
    "&hookrightarrow;": "&#8618;",
    "&larrlp;": "&#8619;",
    "&looparrowleft;": "&#8619;",
    "&rarrlp;": "&#8620;",
    "&looparrowright;": "&#8620;",
    "&harrw;": "&#8621;",
    "&leftrightsquigarrow;": "&#8621;",
    "&nleftrightarrow;": "&#8622;",
    "&nharr;": "&#8622;",
    # downwards zigzag arrow: "&#8623;",
    "&lsh;": "&#8624;",
    "&Lsh;": "&#8624;",
    "&rsh;": "&#8625;",
    "&Rsh;": "&#8625;",
    "&ldsh;": "&#8626;",
    "&rdsh;": "&#8627;",
    # rightwards arrow with corner downwards: "&#8628;",  
    "&crarr;": "&#8629;",
    "&crarr;": "&#8629;",
    "&crarr;": "&#8629;",
    "&cularr;": "&#8630;",
    "&curvearrowleft;": "&#8630;",
    "&curarr;": "&#8631;",
    "&curvearrowright;": "&#8631;",    
    # north west arrow to long bar: "&#8632;",    
    # leftwards arrow to bar over rightwards arrow to bar: "&#8633;",    
    "&olarr;": "&#8634;",
    "&circlearrowleft;": "&#8634;",
    "&orarr;": "&#8635;",
    "&circlearrowright;": "&#8635;",
    "&lharu;": "&#8636;",
    "&LeftVector;": "&#8636;",
    "&leftharpoonup;": "&#8636;",
    "&lhard;": "&#8637;",
    "&leftharpoondown;": "&#8637;",
    "&DownLeftVector;": "&#8637;",
    "&uharr;": "&#8638;",
    "&upharpoonright;": "&#8638;",
    "&RightUpVector;": "&#8638;",
    "&uharl;": "&#8639;",
    "&upharpoonleft;": "&#8639;",
    "&LeftUpVector;": "&#8639;",
    "&rharu;": "&#8640;",
    "&RightVector;": "&#8640;",
    "&rightharpoonup;": "&#8640;",
    "&rhard;": "&#8641;",
    "&rightharpoondown;": "&#8641;",
    "&DownRightVector;": "&#8641;",
    "&dharr;": "&#8642;",
    "&RightDownVector;": "&#8642;",
    "&downharpoonright;": "&#8642;",
    "&dharl;": "&#8643;",
    "&LeftDownVector;": "&#8643;",
    "&downharpoonleft;": "&#8643;",
    "&rlarr;": "&#8644;",
    "&rightleftarrows;": "&#8644;",
    "&RightArrowLeftArrow;": "&#8644;",
    "&udarr;": "&#8645;",
    "&UpArrowDownArrow;": "&#8645;",
    "&lrarr;": "&#8646;",
    "&leftrightarrows;": "&#8646;",
    "&LeftArrowRightArrow;": "&#8646;",
    "&llarr;": "&#8647;",
    "&leftleftarrows;": "&#8647;",
    "&uuarr;": "&#8648;",
    "&upuparrows;": "&#8648;",
    "&rrarr;": "&#8649;",
    "&rightrightarrows;": "&#8649;",
    "&ddarr;": "&#8650;",
    "&downdownarrows;": "&#8650;",
    "&lrhar;": "&#8651;",
    "&ReverseEquilibrium;": "&#8651;",
    "&leftrightharpoons;": "&#8651;",
    "&rlhar;": "&#8652;",
    "&rightleftharpoons;": "&#8652;",
    "&Equilibrium;": "&#8652;",
    "&nlArr;": "&#8653;",
    "&nLeftarrow;": "&#8653;",
    "&nhArr;": "&#8654;",
    "&nLeftrightarrow;": "&#8654;",
    "&nrArr;": "&#8655;",
    "&nRightarrow;": "&#8655;",
    "&lArr;": "&#8656;",
    "&lArr;": "&#8656;",
    "&Leftarrow;": "&#8656;",
    "&DoubleLeftArrow;": "&#8656;",
    "&uArr;": "&#8657;",
    "&Uparrow;": "&#8657;",
    "&DoubleUpArrow;": "&#8657;",
    "&rArr;": "&#8658;",
    "&rArr;": "&#8658;",
    "&rArr;": "&#8658;",
    "&Rightarrow;": "&#8658;",
    "&Implies;": "&#8658;",
    "&DoubleRightArrow;": "&#8658;",
    "&dArr;": "&#8659;",
    "&Downarrow;": "&#8659;",
    "&DoubleDownArrow;": "&#8659;",
    "&hArr;": "&#8660;",
    "&Leftrightarrow;": "&#8660;",
    "&DoubleLeftRightArrow;": "&#8660;",
    "&iff;": "&#8660;",
    "&vArr;": "&#8661;",
    "&Updownarrow;": "&#8661;",
    "&DoubleUpDownArrow;": "&#8661;",
    "&nwArr;": "&#8662;",
    "&neArr;": "&#8663;",
    "&seArr;": "&#8664;",
    "&swArr;": "&#8665;",
    "&lAarr;": "&#8666;",
    "&Lleftarrow;": "&#8666;",
    "&rAarr;": "&#8667;",
    "&Rrightarrow;": "&#8667;",
    # leftwards squiggle arrow: "&#8668;",  
    "&zigrarr;": "&#8669;",
    # 8670-8675: TODO    
    "&larrb;": "&#8676;",
    "&LeftArrowBar;": "&#8676;",
    "&rarrb;": "&#8677;",
    "&RightArrowBar;": "&#8677;",
    # 8678-8692: TODO
    "&duarr;": "&#8693;",
    "&DownArrowUpArrow;": "&#8693;",
    # three rightwards arrows: "&#8694;",    
    # leftwards arrow to bar over rightwards arrow to bar: "&#8695;",    
    # leftwards arrow with vertical stroke: "&#8696;",    
    # left right arrow with vertical stroke: "&#8697;",     
    # leftwards arrow with double vertical stroke: "&#8698;",    
    # rightwards arrow with double vertical stroke: "&#8699;",     
    # left right arrow with double vertical stroke: "&#8700;",    
    "&loarr;": "&#8701;",
    "&roarr;": "&#8702;",
    "&hoarr;": "&#8703;",
    "&forall;": "&#8704;",
    "&ForAll;": "&#8704;",
    "&comp;": "&#8705;",
    "&complement;": "&#8705;",
    "&part;": "&#8706;",
    "&part;": "&#8706;",
    "&exist;": "&#8707;",
    "&Exists;": "&#8707;",
    "&nexist;": "&#8708;",
    "&NotExists;": "&#8708;",
    "&nexists;": "&#8708;",
    "&empty;": "&#8709;",
    "&emptyset;": "&#8709;",
    "&emptyv;": "&#8709;",
    "&varnothing;": "&#8709;",
    # increment": "&#8710;",   
    "&nabla;": "&#8711;",
    "&Del;": "&#8711;",
    "&isin;": "&#8712;",
    "&isinv;": "&#8712;",
    "&Element;": "&#8712;",
    "&in;": "&#8712;",
    "&notin;": "&#8713;",
    "&NotElement;": "&#8713;",
    "&notinva;": "&#8713;",
    # small element of: "&#8714;", 
    "&ni;": "&#8715;",
    "&ReverseElement;": "&#8715;",
    "&ni;": "&#8715;",
    "&niv;": "&#8715;",
    "&SuchThat;": "&#8715;",
    "&notni;": "&#8716;",
    "&notniva;": "&#8716;",
    "&NotReverseElement;": "&#8716;",
    # small contains as member: "&#8717;",  
    # end of proof: "&#8718;",    
    "&prod;": "&#8719;",
    "&Product;": "&#8719;",
    "&coprod;": "&#8720;",
    "&Coproduct;": "&#8720;",
    "&sum;": "&#8721;",
    "&Sum;": "&#8721;",
    "&minus;": "&#8722;",
    "&mnplus;": "&#8723;",
    "&mp;": "&#8723;",
    "&MinusPlus;": "&#8723;",
    "&plusdo;": "&#8724;",
    "&dotplus;": "&#8724;",
    # division slash: "&#8725;",    
    "&setmn;": "&#8726;",
    "&setminus;": "&#8726;",
    "&Backslash;": "&#8726;",
    "&ssetmn;": "&#8726;",
    "&smallsetminus;": "&#8726;",
    "&lowast;": "&#8727;",
    "&compfn;": "&#8728;",
    "&SmallCircle;": "&#8728;",  
    # bullet operator: "&#8729;",   
    "&radic;": "&#8730;",
    "&radic;": "&#8730;",
    "&Sqrt;": "&#8730;",
    # cube root: "&#8731;",       
    # fourth root: "&#8732;", 
    "&prop;": "&#8733;",
    "&prop;": "&#8733;",
    "&propto;": "&#8733;",
    "&Proportional;": "&#8733;",
    "&vprop;": "&#8733;",
    "&varpropto;": "&#8733;",
    "&infin;": "&#8734;",
    "&angrt;": "&#8735;",
    "&ang;": "&#8736;",
    "&angle;": "&#8736;",
    "&angmsd;": "&#8737;",
    "&measuredangle;": "&#8737;",
    "&angsph;": "&#8738;",
    "&mid;": "&#8739;",
    "&VerticalBar;": "&#8739;",
    "&smid;": "&#8739;",
    "&shortmid;": "&#8739;",
    "&nmid;": "&#8740;",
    "&NotVerticalBar;": "&#8740;",
    "&nsmid;": "&#8740;",
    "&nshortmid;": "&#8740;",
    "&nmid;": "&#8740;",
    "&NotVerticalBar;": "&#8740;",
    "&nsmid;": "&#8740;",
    "&nshortmid;": "&#8740;",
    "&par;": "&#8741;",
    "&parallel;": "&#8741;",
    "&DoubleVerticalBar;": "&#8741;",
    "&spar;": "&#8741;",
    "&shortparallel;": "&#8741;",
    "&npar;": "&#8742;",
    "&nparallel;": "&#8742;",
    "&NotDoubleVerticalBar;": "&#8742;",
    "&nspar;": "&#8742;",
    "&nshortparallel;": "&#8742;",
    "&and;": "&#8743;",
    "&wedge;": "&#8743;",
    "&or;": "&#8744;",
    "&vee;": "&#8744;",
    "&cap;": "&#8745;",
    "&cup;": "&#8746;",
    "&int;": "&#8747;",
    "&Integral;": "&#8747;",
    "&Int;": "&#8748;",
    "&tint;": "&#8749;",
    "&iiint;": "&#8749;",
    "&conint;": "&#8750;",
    "&oint;": "&#8750;",
    "&ContourIntegral;": "&#8750;",
    "&Conint;": "&#8751;",
    "&DoubleContourIntegral;": "&#8751;",
    "&Cconint;": "&#8752;",
    "&cwint;": "&#8753;",
    "&cwconint;": "&#8754;",
    "&ClockwiseContourIntegral;": "&#8754;",
    "&awconint;": "&#8755;",
    "&CounterClockwiseContourIntegral;": "&#8755;",
    "&there4;": "&#8756;",
    "&therefore;": "&#8756;",
    "&Therefore;": "&#8756;",
    "&becaus;": "&#8757;",
    "&because;": "&#8757;",
    "&Because;": "&#8757;",
    "&ratio;": "&#8758;",
    "&Colon;": "&#8759;",
    "&Proportion;": "&#8759;",
    "&minusd;": "&#8760;",
    "&dotminus;": "&#8760;",
    # excess: "&#8761;",    
    "&mDDot;": "&#8762;",
    "&homtht;": "&#8763;",
    "&sim;": "&#8764;",
    "&Tilde;": "&#8764;",
    "&thksim;": "&#8764;",
    "&thicksim;": "&#8764;",
    "&bsim;": "&#8765;",
    "&backsim;": "&#8765;",
    "&ac;": "&#8766;",
    "&mstpos;": "&#8766;",
    "&acd;": "&#8767;",
    "&wreath;": "&#8768;",
    "&VerticalTilde;": "&#8768;",
    "&wr;": "&#8768;",
    "&nsim;": "&#8769;",
    "&NotTilde;": "&#8769;",
    "&esim;": "&#8770;",
    "&EqualTilde;": "&#8770;",
    "&eqsim;": "&#8770;",
    "&sime;": "&#8771;",
    "&TildeEqual;": "&#8771;",
    "&simeq;": "&#8771;",
    "&nsime;": "&#8772;",
    "&nsimeq;": "&#8772;",
    "&NotTildeEqual;": "&#8772;",
    "&cong;": "&#8773;",
    "&TildeFullEqual;": "&#8773;",
    "&simne;": "&#8774;",
    "&ncong;": "&#8775;",
    "&NotTildeFullEqual;": "&#8775;",
    "&asymp;": "&#8776;",
    "&ap;": "&#8776;",
    "&TildeTilde;": "&#8776;",
    "&approx;": "&#8776;",
    "&thkap;": "&#8776;",
    "&thickapprox;": "&#8776;",
    "&nap;": "&#8777;",
    "&NotTildeTilde;": "&#8777;",
    "&napprox;": "&#8777;",
    "&ape;": "&#8778;",
    "&approxeq;": "&#8778;",
    "&apid;": "&#8779;",
    "&bcong;": "&#8780;",
    "&backcong;": "&#8780;",
    "&asympeq;": "&#8781;",
    "&CupCap;": "&#8781;",
    "&bump;": "&#8782;",
    "&HumpDownHump;": "&#8782;",
    "&Bumpeq;": "&#8782;",
    "&bumpe;": "&#8783;",
    "&HumpEqual;": "&#8783;",
    "&bumpeq;": "&#8783;",
    "&esdot;": "&#8784;",
    "&DotEqual;": "&#8784;",
    "&doteq;": "&#8784;",
    "&eDot;": "&#8785;",
    "&doteqdot;": "&#8785;",
    "&efDot;": "&#8786;",
    "&fallingdotseq;": "&#8786;",
    "&erDot;": "&#8787;",
    "&risingdotseq;": "&#8787;",
    "&colone;": "&#8788;",
    "&coloneq;": "&#8788;",
    "&eqcolon;": "&#8789;",
    "&ecir;": "&#8790;",
    "&eqcirc;": "&#8790;",
    "&cire;": "&#8791;",
    "&circeq;": "&#8791;",
    # corresponds to: "&#8792;",    
    "&wedgeq;": "&#8793;",
    # equilinear to: "&#8794;",
    # star equals: "&#8795;",   
    "&trie;": "&#8796;",
    "&triangleq;": "&#8796;",
    # equal to by definition: "&#8797;",
    "&triangleq;": "&#8798;",
    "&equest;": "&#8799;",
    "&questeq;": "&#8799;",
    "&ne;": "&#8800;",
    "&NotEqual;": "&#8800;",
    "&Congruent;": "&#8801;",
    "&equiv;": "&#8801;",
    "&nequiv;": "&#8802;",
    "&NotCongruent;": "&#8802;",
    # strictly equivalent to: "&#8803;",    
    "&le;": "&#8804;",
    "&leq;": "&#8804;",
    "&ge;": "&#8805;",
    "&GreaterEqual;": "&#8805;",
    "&geq;": "&#8805;",
    "&lE;": "&#8806;",
    "&LessFullEqual;": "&#8806;",
    "&leqq;": "&#8806;",
    "&gE;": "&#8807;",
    "&GreaterFullEqual;": "&#8807;",
    "&geqq;": "&#8807;",
    "&lnE;": "&#8808;",
    "&lneqq;": "&#8808;",
    "&gnE;": "&#8809;",
    "&gneqq;": "&#8809;",
    "&Lt;": "&#8810;",
    "&NestedLessLess;": "&#8810;",
    "&ll;": "&#8810;",
    "&Gt;": "&#8811;",
    "&NestedGreaterGreater;": "&#8811;",
    "&gg;": "&#8811;",
    "&twixt;": "&#8812;",
    "&between;": "&#8812;",
    "&NotCupCap;": "&#8813;",
    "&nlt;": "&#8814;",
    "&NotLess;": "&#8814;",
    "&nless;": "&#8814;",
    "&ngt;": "&#8815;",
    "&NotGreater;": "&#8815;",
    "&ngtr;": "&#8815;",
    "&nle;": "&#8816;",
    "&NotLessEqual;": "&#8816;",
    "&nleq;": "&#8816;",
    "&nge;": "&#8817;",
    "&NotGreaterEqual;": "&#8817;",
    "&ngeq;": "&#8817;",
    "&lsim;": "&#8818;",
    "&LessTilde;": "&#8818;",
    "&lesssim;": "&#8818;",
    "&gsim;": "&#8819;",
    "&gtrsim;": "&#8819;",
    "&GreaterTilde;": "&#8819;",
    "&nlsim;": "&#8820;",
    "&NotLessTilde;": "&#8820;",
    "&ngsim;": "&#8821;",
    "&NotGreaterTilde;": "&#8821;",
    "&lg;": "&#8822;",
    "&lessgtr;": "&#8822;",
    "&LessGreater;": "&#8822;",
    "&gl;": "&#8823;",
    "&gtrless;": "&#8823;",
    "&GreaterLess;": "&#8823;",
    "&ntlg;": "&#8824;",
    "&NotLessGreater;": "&#8824;",
    "&ntgl;": "&#8825;",
    "&NotGreaterLess;": "&#8825;",
    "&pr;": "&#8826;",
    "&Precedes;": "&#8826;",
    "&prec;": "&#8826;",
    "&sc;": "&#8827;",
    "&Succeeds;": "&#8827;",
    "&succ;": "&#8827;",
    "&prcue;": "&#8828;",
    "&PrecedesSlantEqual;": "&#8828;",
    "&preccurlyeq;": "&#8828;",
    "&sccue;": "&#8829;",
    "&SucceedsSlantEqual;": "&#8829;",
    "&succcurlyeq;": "&#8829;",
    "&prsim;": "&#8830;",
    "&precsim;": "&#8830;",
    "&PrecedesTilde;": "&#8830;",
    "&scsim;": "&#8831;",
    "&succsim;": "&#8831;",
    "&SucceedsTilde;": "&#8831;",
    "&npr;": "&#8832;",
    "&nprec;": "&#8832;",
    "&NotPrecedes;": "&#8832;",
    "&nsc;": "&#8833;",
    "&nsucc;": "&#8833;",
    "&NotSucceeds;": "&#8833;",
    "&sub;": "&#8834;",
    "&sub;": "&#8834;",
    "&sub;": "&#8834;",
    "&subset;": "&#8834;",
    "&sup;": "&#8835;",
    "&sup;": "&#8835;",
    "&sup;": "&#8835;",
    "&supset;": "&#8835;",
    "&Superset;": "&#8835;",
    "&nsub;": "&#8836;",
    "&nsub;": "&#8836;",
    "&nsup;": "&#8837;",
    "&sube;": "&#8838;",
    "&sube;": "&#8838;",
    "&sube;": "&#8838;",
    "&SubsetEqual;": "&#8838;",
    "&subseteq;": "&#8838;",
    "&supe;": "&#8839;",
    "&supe;": "&#8839;",
    "&supe;": "&#8839;",
    "&supseteq;": "&#8839;",
    "&SupersetEqual;": "&#8839;",
    "&nsube;": "&#8840;",
    "&nsubseteq;": "&#8840;",
    "&NotSubsetEqual;": "&#8840;",
    "&nsupe;": "&#8841;",
    "&nsupseteq;": "&#8841;",
    "&NotSupersetEqual;": "&#8841;",
    "&subne;": "&#8842;",
    "&subsetneq;": "&#8842;",
    "&supne;": "&#8843;",
    "&supsetneq;": "&#8843;",
    # multiset: "&#8844;",   
    "&cupdot;": "&#8845;",
    "&uplus;": "&#8846;",
    "&UnionPlus;": "&#8846;",
    "&sqsub;": "&#8847;",
    "&SquareSubset;": "&#8847;",
    "&sqsubset;": "&#8847;",
    "&sqsup;": "&#8848;",
    "&SquareSuperset;": "&#8848;",
    "&sqsupset;": "&#8848;",
    "&sqsube;": "&#8849;",
    "&SquareSubsetEqual;": "&#8849;",
    "&sqsubseteq;": "&#8849;",
    "&sqsupe;": "&#8850;",
    "&SquareSupersetEqual;": "&#8850;",
    "&sqsupseteq;": "&#8850;",
    "&sqcap;": "&#8851;",
    "&SquareIntersection;": "&#8851;",
    "&sqcup;": "&#8852;",
    "&SquareUnion;": "&#8852;",
    "&oplus;": "&#8853;",
    "&oplus;": "&#8853;",
    "&CirclePlus;": "&#8853;",
    "&ominus;": "&#8854;",
    "&CircleMinus;": "&#8854;",
    "&otimes;": "&#8855;",
    "&CircleTimes;": "&#8855;",
    "&osol;": "&#8856;",
    "&odot;": "&#8857;",
    "&CircleDot;": "&#8857;",
    "&ocir;": "&#8858;",
    "&circledcirc;": "&#8858;",
    "&oast;": "&#8859;",
    "&circledast;": "&#8859;",
    # circled equals: "&#8860;",    
    "&odash;": "&#8861;",
    "&circleddash;": "&#8861;",
    "&plusb;": "&#8862;",
    "&boxplus;": "&#8862;",
    "&minusb;": "&#8863;",
    "&boxminus;": "&#8863;",
    "&timesb;": "&#8864;",
    "&boxtimes;": "&#8864;",
    "&sdotb;": "&#8865;",
    "&dotsquare;": "&#8865;",
    "&vdash;": "&#8866;",
    "&RightTee;": "&#8866;",
    "&dashv;": "&#8867;",
    "&LeftTee;": "&#8867;",
    "&top;": "&#8868;",
    "&DownTee;": "&#8868;",
    "&bottom;": "&#8869;",
    "&bot;": "&#8869;",
    "&perp;": "&#8869;",
    "&UpTee;": "&#8869;",
    "&perp;": "&#8869;",
    # assertion: "&#8870;",
    "&models;": "&#8871;",
    "&vDash;": "&#8872;",
    "&DoubleRightTee;": "&#8872;",
    "&Vdash;": "&#8873;",
    "&Vvdash;": "&#8874;",
    "&VDash;": "&#8875;",
    "&nvdash;": "&#8876;",
    "&nvDash;": "&#8877;",
    "&nVdash;": "&#8878;",
    "&nVDash;": "&#8879;",
    "&prurel;": "&#8880;",
    # succeeds under relation: "&#8881;",    
    "&vltri;": "&#8882;",
    "&vartriangleleft;": "&#8882;",
    "&LeftTriangle;": "&#8882;",
    "&vrtri;": "&#8883;",
    "&vartriangleright;": "&#8883;",
    "&RightTriangle;": "&#8883;",
    "&ltrie;": "&#8884;",
    "&trianglelefteq;": "&#8884;",
    "&LeftTriangleEqual;": "&#8884;",
    "&rtrie;": "&#8885;",
    "&trianglerighteq;": "&#8885;",
    "&RightTriangleEqual;": "&#8885;",
    "&origof;": "&#8886;",
    "&imof;": "&#8887;",
    "&mumap;": "&#8888;",
    "&multimap;": "&#8888;",
    "&hercon;": "&#8889;",
    "&intcal;": "&#8890;",
    "&intercal;": "&#8890;",
    "&veebar;": "&#8891;",
    # nand: "&#8892;",
    "&barvee;": "&#8893;",
    "&angrtvb;": "&#8894;",
    "&lrtri;": "&#8895;",
    "&xwedge;": "&#8896;",
    "&Wedge;": "&#8896;",
    "&bigwedge;": "&#8896;",
    "&xvee;": "&#8897;",
    "&Vee;": "&#8897;",
    "&bigvee;": "&#8897;",
    "&xcap;": "&#8898;",
    "&Intersection;": "&#8898;",
    "&bigcap;": "&#8898;",
    "&xcup;": "&#8899;",
    "&Union;": "&#8899;",
    "&bigcup;": "&#8899;",
    "&diam;": "&#8900;",
    "&diamond;": "&#8900;",
    "&Diamond;": "&#8900;",
    "&sdot;": "&#8901;",
    "&sdot;": "&#8901;",
    "&sdot;": "&#8901;",
    "&sstarf;": "&#8902;",
    "&Star;": "&#8902;",
    "&divonx;": "&#8903;",
    "&divideontimes;": "&#8903;",
    "&bowtie;": "&#8904;",
    "&ltimes;": "&#8905;",
    "&rtimes;": "&#8906;",
    "&lthree;": "&#8907;",
    "&leftthreetimes;": "&#8907;",
    "&rthree;": "&#8908;",
    "&rightthreetimes;": "&#8908;",
    "&bsime;": "&#8909;",
    "&backsimeq;": "&#8909;",
    "&cuvee;": "&#8910;",
    "&curlyvee;": "&#8910;",
    "&cuwed;": "&#8911;",
    "&curlywedge;": "&#8911;",
    "&Sub;": "&#8912;",
    "&Subset;": "&#8912;",
    "&Sup;": "&#8913;",
    "&Supset;": "&#8913;",
    "&Cap;": "&#8914;",
    "&Cup;": "&#8915;",
    "&fork;": "&#8916;",
    "&pitchfork;": "&#8916;",
    "&epar;": "&#8917;",
    "&ltdot;": "&#8918;",
    "&lessdot;": "&#8918;",
    "&gtdot;": "&#8919;",
    "&gtrdot;": "&#8919;",
    "&Ll;": "&#8920;",
    "&Gg;": "&#8921;",
    "&ggg;": "&#8921;",
    "&leg;": "&#8922;",
    "&LessEqualGreater;": "&#8922;",
    "&lesseqgtr;": "&#8922;",
    "&gel;": "&#8923;",
    "&gtreqless;": "&#8923;",
    "&GreaterEqualLess;": "&#8923;",
    # equal to or less than: "&#8924;",   
    # equal to or greater than: "&#8925;",    
    "&cuepr;": "&#8926;",
    "&curlyeqprec;": "&#8926;",
    "&cuesc;": "&#8927;",
    "&curlyeqsucc;": "&#8927;",
    "&nprcue;": "&#8928;",
    "&NotPrecedesSlantEqual;": "&#8928;",
    "&nsccue;": "&#8929;",
    "&NotSucceedsSlantEqual;": "&#8929;",
    "&nsqsube;": "&#8930;",
    "&NotSquareSubsetEqual;": "&#8930;",
    "&nsqsupe;": "&#8931;",
    "&NotSquareSupersetEqual;": "&#8931;",
    # equal to or less than: "&#8932;",   
    # equal to or greater than: "&#8933;",  
    "&lnsim;": "&#8934;",
    "&gnsim;": "&#8935;",
    "&prnsim;": "&#8936;",
    "&precnsim;": "&#8936;",
    "&scnsim;": "&#8937;",
    "&succnsim;": "&#8937;",
    "&nltri;": "&#8938;",
    "&ntriangleleft;": "&#8938;",
    "&NotLeftTriangle;": "&#8938;",
    "&nrtri;": "&#8939;",
    "&ntriangleright;": "&#8939;",
    "&NotRightTriangle;": "&#8939;",
    "&NotLeftTriangleEqual;": "&#8940;",
    "&ntrianglelefteq;": "&#8940;",
    "&NotLeftTriangleEqual;": "&#8940;",
    "&nrtrie;": "&#8941;",
    "&ntrianglerighteq;": "&#8941;",
    "&NotRightTriangleEqual;": "&#8941;",
    "&vellip;": "&#8942;",
    "&ctdot;": "&#8943;",
    "&utdot;": "&#8944;",
    "&dtdot;": "&#8945;",
    "&disin;": "&#8946;",
    "&isinsv;": "&#8947;",
    "&isins;": "&#8948;",
    "&isindot;": "&#8949;",
    "&notinvc;": "&#8950;",
    "&notinvb;": "&#8951;",
    # Element of with Underbar: "&#8952;",
    "&isinE;": "&#8953;",
    "&nisd;": "&#8954;",
    "&xnis;": "&#8955;",
    "&nis;": "&#8956;",
    "&notnivc;": "&#8957;",
    "&notnivb;": "&#8958;",
    # z notation bag membership: "&#8959;",
    # diameter sign: "&#8960;",
    # electric arrow: "&#8961;",
    # house: "&#8962;",
    # up arrowhead: "&#8963;",
    # down arrowhead: "&#8964;",
    "&barwed;": "&#8965;",
    "&barwedge;": "&#8965;",
    "&Barwed;": "&#8966;",
    "&doublebarwedge;": "&#8966;",
    # wavy line: "&#8967;",    
    "&lceil;": "&#8968;",
    "&lceil;": "&#8968;",
    "&lceil;": "&#8968;",
    "&LeftCeiling;": "&#8968;",
    "&rceil;": "&#8969;",
    "&rceil;": "&#8969;",
    "&rceil;": "&#8969;",
    "&RightCeiling;": "&#8969;",
    "&lfloor;": "&#8970;",
    "&lfloor;": "&#8970;",
    "&lfloor;": "&#8970;",
    "&LeftFloor;": "&#8970;",
    "&rfloor;": "&#8971;",
    "&rfloor;": "&#8971;",
    "&rfloor;": "&#8971;",
    "&RightFloor;": "&#8971;",
    "&drcrop;": "&#8972;",
    "&dlcrop;": "&#8973;",
    "&urcrop;": "&#8974;",
    "&ulcrop;": "&#8975;",
    "&bnot;": "&#8976;",
    # square lozenge: "&#8977;",    
    "&profline;": "&#8978;",
    "&profsurf;": "&#8979;",
    # sector: "&#8980;",    
    "&telrec;": "&#8981;",
    "&target;": "&#8982;",    
    # viewdata square: "&#8983;",
    # place of interest sign: "&#8984;",
    # turned not sign: "&#8985;",
    # watch: "&#8986;",
    # hourglass: "&#8987;",
    "&ulcorn;": "&#8988;",
    "&ulcorner;": "&#8988;",
    "&urcorn;": "&#8989;",
    "&urcorner;": "&#8989;",
    "&dlcorn;": "&#8990;",
    "&llcorner;": "&#8990;",
    "&drcorn;": "&#8991;",
    "&lrcorner;": "&#8991;",
    # top half integral: "&#8992;",    
    # bottom half integral: "&#8993;",    
    "&frown;": "&#8994;",
    "&sfrown;": "&#8994;",
    "&smile;": "&#8995;",
    "&ssmile;": "&#8995;",
    # up arrowhead between two horizontal bars: "&#8996;",   
    # option key: "&#8997;",    
    # erase to the right: "&#8998;",
    # x in a rectangle box: "&#8999;",    
    # keyboard: "&#9000;",    
    "&lang;": "&#9001;",
    "&lang;": "&#9001;",
    "&rang;": "&#9002;",
    "&rang;": "&#9002;",
    # erase to the left: "&#9003;",
    # benzene ring: "&#9004;" 
    "&cylcty;": "&#9005;",
    "&profalar;": "&#9006;",
    # symmetry: "&#9007;",   
    # total runout: "&#9008;",    
    # dimension origin: "&#9009;",   
    # conical taper: "&#9010;", 
    # slope: "&#9011;",    
    # counterbore: "&#9012;",       
    # countersink: "&#9013;",      
    "&topbot;": "&#9014;",
    # APL functional symbol squish quad: "&#9015;",    
    # APL functional symbol quad equal: "&#9016;",   
    # APL functional symbol quad divide: "&#9017;",    
    # APL functional symbol quad diamond: "&#9018;",   
    # APL functional symbol quad jot: "&#9019;",   
    # APL functional symbol quad circle: "&#9020;",   
    "&ovbar;": "&#9021;",
    # APL functional symbol circle jot: "&#9022;",     
    "&solbar;": "&#9023;",
    # 9024-9083: TODO
    "&angzarr;": "&#9084;",
    # 9085-9135: TODO 
    "&lmoust;": "&#9136;",
    "&lmoustache;": "&#9136;",
    "&rmoust;": "&#9137;",
    "&rmoustache;": "&#9137;",
    # summation top: "&#9138;",
    # summation bottom: "&#9139;",
    "&tbrk;": "&#9140;",
    "&OverBracket;": "&#9140;",
    "&bbrk;": "&#9141;",
    "&UnderBracket;": "&#9141;",
    "&bbrktbrk;": "&#9142;",
    # 9143-9179: TODO 
    "&OverParenthesis;": "&#9180;",
    "&UnderParenthesis;": "&#9181;",
    "&OverBrace;": "&#9182;",
    # bottom curly bracket: "&#9183;",
    # top tortoise shell bracket: "&#9184;",   
    # bottom tortoise shell bracket: "&#9185;",   
    "&trpezium;": "&#9186;",
    # bottom curly bracket: "&#9187;",    
    # straightness: "&#9188;",   
    # flatness: "&#9189;",    
    # ac current: "&#9190;",
    "&elinters;": "&#9191;",
    # 9192-9250: TODO    
    "&blank;": "&#9251;",
    # 9252-9415: TODO 
    "&oS;": "&#9416;",
    "&circledS;": "&#9416;",
    # 9417-9471: TODO 
    "&boxh;": "&#9472;",
    # box drawings light horizontal: "&#9472;",
    # box drawings heavy horizontal: "&#9473;",
    "&boxv;": "&#9474;",
    # box drawings heavy vertical: "&#9475;",
    # box drawings light triple dash horizontal: "&#9476;",
    # box drawings heavy triple dash horizontal: "&#9477;",
    # box drawings light triple dash vertical: "&#9478;",
    # box drawings heavy triple dash vertical: "&#9479;",
    # box drawings light quadruple dash horizontal: "&#9480;", 
    # box drawings heavy quadruple dash horizontal: "&#9481;",
    # box drawings light quadruple dash vertical: "&#9482;",
    # box drawings heavy quadruple dash vertical: "&#9483;",
    "&boxdr;": "&#9484;",
    # box drawings down light and right heavy: "&#9485;",
    # box drawings down heavy and right light: "&#9486;",
    # box drawings heavy down and right: "&#9487;",    
    "&boxdl;": "&#9488;",
    # box drawings down light and left heavy: "&#9489;", 
    # box drawings down heavy and left light: "&#9490;", 
    # box drawings heavy down and left: "&#9491;",   
    "&boxur;": "&#9492;",
    # box drawings down light and left heavy: "&#9493;", 
    # box drawings down heavy and left light: "&#9494;", 
    # box drawings heavy down and left: "&#9495;",  
    "&boxul;": "&#9496;",
    # box drawings up light and left heavy: "&#9497;", 
    # box drawings up heavy and left light: "&#9498;",   
    # box drawings heavy up and left: "&#9499;",      
    "&boxvr;": "&#9500;",
    # box drawings vertical light and right heavy: "&#9501;",   
    # box drawings heavy down and left: "&#9502;",   
    # box drawings up heavy and right down light: "&#9503;",      
    # box drawings vertical heavy and right light: "&#9504;",   
    # box drawings down light and right up heavy: "&#9505;",   
    # box drawings up light and right down heavy: "&#9506;",      
    # box drawings heavy vertical and right: "&#9507;",    
    "&boxvl;": "&#9508;",  
    # box drawings vertical light and left heavy: "&#9509;", 
    # box drawings up heavy and left down light: "&#9510;", 
    # box drawings down heavy and left up light: "&#9511;", 
    # box drawings vertical heavy and left light: "&#9512;", 
    # box drawings down light and left up heavy: "&#9513;", 
    # box drawings up light and left down heavy: "&#9514;",     
    # box drawings heavy vertical and left: "&#9515;",     
    "&boxhd;": "&#9516;",
    # box drawings left heavy and right down light: "&#9517;", 
    # box drawings right heavy and left down light: "&#9518;",   
    # box drawings down light and horizontal heavy: "&#9519;",     
    # box drawings down heavy and horizontal light: "&#9520;", 
    # box drawings right light and left down heavy: "&#9521;",   
    # box drawings left light and right down heavy: "&#9522;",     
    # box drawings heavy down and horizontal: "&#9523;",
    "&boxhu;": "&#9524;",
    # box drawings left heavy and right up light: "&#9525;", 
    # box drawings right heavy and left up light: "&#9526;", 
    # box drawings up light and horizontal heavy: "&#9527;",   
    # box drawings up heavy and horizontal light: "&#9528;", 
    # box drawings right light and left up heavy: "&#9529;", 
    # box drawings left light and right up heavy: "&#9530;",
    # box drawings heavy up and horizontal: "&#9531;",   
    "&boxvh;": "&#9532;",    
    # box drawings left heavy and right vertical light: "&#9533;", 
    # right heavy and left vertical light: "&#9534;",
    # vertical light and horizontal heavy: "&#9535;",
    # up heavy and down horizontal light: "&#9536;",
    # down heavy and up horizontal light: "&#9537;",
    # vertical heavy and horizontal light: "&#9538;",
    # left up heavy and right down light: "&#9539;",
    # right up heavy and left down light: "&#9540;",
    # left down heavy and right up light: "&#9541;",
    # right down heavy and left up light: "&#9542;",
    # down light and up horizontal heavy: "&#9543;",
    # up light and down horizontal heavy: "&#9544;",
    # right light and left vertical heavy: "&#9545;",
    # left light and right vertical heavy: "&#9546;",   
    # heavy vertical and horizontal: "&#9547;",
    # light double dash horizontal: "&#9548;",
    # heavy double dash horizontal: "&#9549;",
    # light double dash vertical: "&#9550;",
    # heavy double dash vertical: "&#9551;",
    "&boxH;": "&#9552;",
    "&boxV;": "&#9553;",
    "&boxdR;": "&#9554;",
    "&boxDr;": "&#9555;",
    "&boxDR;": "&#9556;",
    "&boxdL;": "&#9557;",
    "&boxDl;": "&#9558;",
    "&boxDL;": "&#9559;",
    "&boxuR;": "&#9560;",
    "&boxUr;": "&#9561;",
    "&boxUR;": "&#9562;",
    "&boxuL;": "&#9563;",
    "&boxUl;": "&#9564;",
    "&boxUL;": "&#9565;",
    "&boxvR;": "&#9566;",
    "&boxVr;": "&#9567;",
    "&boxVR;": "&#9568;",
    "&boxvL;": "&#9569;",
    "&boxVl;": "&#9570;",
    "&boxVL;": "&#9571;",
    "&boxHd;": "&#9572;",
    "&boxhD;": "&#9573;",
    "&boxHD;": "&#9574;",
    "&boxHu;": "&#9575;",
    "&boxhU;": "&#9576;",
    "&boxHU;": "&#9577;",
    "&boxvH;": "&#9578;",
    "&boxVh;": "&#9579;",
    "&boxVH;": "&#9580;",
    # 9581-9599: TODO        
    "&uhblk;": "&#9600;",
    # lower one eighth block: "&#9601;",    
    # lower one quarter block: "&#9602;",    
    # lower three eighths block: "&#9603;",
    "&lhblk;": "&#9604;",
    # lower five eighths block: "&#9605;",    
    # lower three quarters block: "&#9606;",    
    # lower seven eighths block: "&#9607;",    
    # full block: "&#9608;",
    # left seven eighths block: "&#9609;",
    # left three quarters block: "&#9610;",
    # left five eighths block: "&#9611;", 
    # left half block: "&#9612;",
    # left three eighths block: "&#9613;",
    # left one quarter block: "&#9614;",
    # left one eighth block: "&#9615;",
    # right half block: "&#9616;",
    # light shade: "&#9617;",
    # medium shade: "&#9618;",
    # dark shade: "&#9619;",
    # upper one eighth block: "&#9620;",
    # right one eighth block: "&#9621;",
    # quadrant lower left: "&#9622;",   
    # quadrant lower right: "&#9623;",
    # quadrant upper left: "&#9624;",
    # quadrant upper left and lower left and lower right: "&#9625;",   
    # quadrant upper left and lower right: "&#9626;",
    # quadrant upper left and upper right and lower left: "&#9627;",
    # quadrant upper left and upper right and lower right: "&#9628;",    
    # quadrant upper right: "&#9629;",
    # quadrant upper right and lower left: "&#9630;",
    # quadrant upper right and lower left and lower right: "&#9631;",   
    # black square: "&#9632;",  
    # white square: "&#9633;",
    "&square;": "&#9633;",
    "&Square;": "&#9633;",
    # box drawings right heavy and left vertical light: "&#9634;",
    # box drawings vertical light and horizontal heavy: "&#9635;",
    # box drawings up heavy and down horizontal light: "&#9636;",
    # box drawings down heavy and up horizontal light: "&#9637;",
    # box drawings vertical heavy and horizontal light: "&#9638;",
    # box drawings left up heavy and right down light: "&#9639;",
    # box drawings right up heavy and left down light: "&#9640;",
    # box drawings left down heavy and right up light: "&#9641;",  
    "&squf;": "&#9642;",
    "&squarf;": "&#9642;",
    "&blacksquare;": "&#9642;",
    "&FilledVerySmallSquare;": "&#9642;",
    "&EmptyVerySmallSquare;": "&#9643;",
    # black rectangle": "&#9644;",      
    "&rect;": "&#9645;",
    "&marker;": "&#9646;",
    # white vertical rectangle: "&#9647;",
    # black parallelogram: "&#9648;",
    # white parallelogram: "&#9649;",
    # black up-pointing triangle: "&#9650;",    
    "&xutri;": "&#9651;",
    "&bigtriangleup;": "&#9651;",
    "&utrif;": "&#9652;",
    "&blacktriangle;": "&#9652;",
    "&utri;": "&#9653;",
    "&utri;": "&#9653;",
    "&triangle;": "&#9653;",
    # black right-pointing triangle: "&#9654;",
    # white right-pointing triangle: "&#9655;",
    "&rtrif;": "&#9656;",
    "&blacktriangleright;": "&#9656;",
    "&rtri;": "&#9657;",
    "&triangleright;": "&#9657;",
    # black right-pointing pointer: "&#9658;",
    # white right-pointing pointer: "&#9659;",
    # black down-pointing triangle: "&#9660;",
    "&xdtri;": "&#9661;",
    "&bigtriangledown;": "&#9661;",
    "&dtrif;": "&#9662;",
    "&blacktriangledown;": "&#9662;",
    "&dtri;": "&#9663;",
    "&triangledown;": "&#9663;",
    # black left-pointing triangle: "&#9664;",   
    # white left-pointing triangle: "&#9665;",       
    "&ltrif;": "&#9666;",
    "&blacktriangleleft;": "&#9666;",
    "&ltri;": "&#9667;",
    "&triangleleft;": "&#9667;",
    # black left-pointing pointer: "&#9668;", 
    # white left-pointing pointer: "&#9669;",   
    # black diamond: "&#9670;", 
    # white diamond: "&#9671;",    
    # white diamond containing black small diamond: "&#9672;", 
    # fisheye: "&#9673;",      
    "&loz;": "&#9674;",
    "&lozenge;": "&#9674;",
    "&cir;": "&#9675;",
    # 9676-9707: TODO   
    "&tridot;": "&#9708;",
    # 9709-9710: TODO      
    "&xcirc;": "&#9711;",
    "&bigcirc;": "&#9711;",
    # 9712-9719: TODO      
    "&ultri;": "&#9720;",
    "&urtri;": "&#9721;",
    "&lltri;": "&#9722;",
    "&EmptySmallSquare;": "&#9723;",
    "&FilledSmallSquare;": "&#9724;",
    # 9725-9732: TODO        
    "&starf;": "&#9733;",
    "&bigstar;": "&#9733;",
    "&star;": "&#9734;",
    # 9735-9741: TODO    
    "&phone;": "&#9742;",
    # 9743-9791: TODO      
    "&female;": "&#9792;",
    # earth "&#9793;",
    "&male;": "&#9794;",
    # 9795-9823: TODO
    "&spades;": "&#9824;",
    "&spadesuit;": "&#9824;",
    # 9825-9826: TODO    
    "&clubs;": "&#9827;",
    "&clubsuit;": "&#9827;",
    # black club suit: "&#9828;",    
    "&hearts;": "&#9829;",
    "&heartsuit;": "&#9829;",
    "&diamondsuit;": "&#9830;",
    "&diams;": "&#9830;",
    # 9831-9833: TODO    
    "&sung;": "&#9834;",
    # 9835-9836: TODO    
    "&flat;": "&#9837;",
    "&natur;": "&#9838;",
    "&natural;": "&#9838;",
    "&sharp;": "&#9839;",
    # 9840-10002: TODO 
    "&check;": "&#10003;",
    "&checkmark;": "&#10003;",
    # 10004-10006: TODO
    "&cross;": "&#10007;",
    # 10008-10015: TODO
    "&malt;": "&#10016;",
    "&maltese;": "&#10016;",
    # 10017-10037: TODO 
    "&sext;": "&#10038;",
    # 10039-10071: TODO 
    "&VerticalSeparator;": "&#10072;",
    # 10073-10097: TODO 
    "&lbbrk;": "&#10098;",
    "&rbbrk;": "&#10099;",
    # 10100-10213: TODO 
    "&LeftDoubleBracket;": "&#10214;",
    "&lobrk;": "&#10214;",
    "&RightDoubleBracket;": "&#10215;",
    "&robrk;": "&#10215;",
    "&lang;": "&#10216;",
    "&langle;": "&#10216;",
    "&LeftAngleBracket;": "&#10216;",
    "&rang;": "&#10217;",
    "&rangle;": "&#10217;",
    "&RightAngleBracket;": "&#10217;",
    "&Lang;": "&#10218;",
    "&Rang;": "&#10219;",
    "&loang;": "&#10220;",
    "&roang;": "&#10221;",
    # 10222-10228: TODO    
    "&longleftarrow;": "&#10229;",
    "&LongLeftArrow;": "&#10229;",
    "&xlarr;": "&#10229;",
    "&longrightarrow;": "&#10230;",
    "&LongRightArrow;": "&#10230;",
    "&xrarr;": "&#10230;",
    "&xharr;": "&#10231;",
    "&longleftrightarrow;": "&#10231;",
    "&LongLeftRightArrow;": "&#10231;",
    "&xlArr;": "&#10232;",
    "&Longleftarrow;": "&#10232;",
    "&DoubleLongLeftArrow;": "&#10232;",
    "&xrArr;": "&#10233;",
    "&Longrightarrow;": "&#10233;",
    "&DoubleLongRightArrow;": "&#10233;",
    "&xhArr;": "&#10234;",
    "&Longleftrightarrow;": "&#10234;",
    "&DoubleLongLeftRightArrow;": "&#10234;",
    # long leftwards arrow from bar: "&#10235;",    
    "&xmap;": "&#10236;",
    "&longmapsto;": "&#10236;",
    # long leftwards double arrow from bar: "&#10237;",    
    # long rightwards double arrow from bar": "&#10238;",    
    "&dzigrarr;": "&#10239;",
    # 10240-10497: TODO 
    "&nvlArr;": "&#10498;",
    "&nvrArr;": "&#10499;",
    "&nvHarr;": "&#10500;",
    "&Map;": "&#10501;",
    # 10502-10507: TODO     
    "&lbarr;": "&#10508;",
    "&rbarr;": "&#10509;",
    "&bkarow;": "&#10509;",
    "&lBarr;": "&#10510;",
    "&rBarr;": "&#10511;",
    "&dbkarow;": "&#10511;",
    "&RBarr;": "&#10512;",
    "&drbkarow;": "&#10512;",
    "&DDotrahd;": "&#10513;",
    "&UpArrowBar;": "&#10514;",
    "&DownArrowBar;": "&#10515;",
    # rightwards arrow with tail with vertical stroke: "&#10516;",    
    # rightwards arrow with tail with double vertical stroke: "&#10517;",
    "&Rarrtl;": "&#10518;",
    # rightwards two-headed arrow with tail with vertical stroke: "&#10519;",
    # [not found]: "&#10520;",
    "&latail;": "&#10521;",
    "&ratail;": "&#10522;",
    "&lAtail;": "&#10523;",
    "&rAtail;": "&#10524;",
    "&larrfs;": "&#10525;",
    "&rarrfs;": "&#10526;",
    "&larrbfs;": "&#10527;",
    "&rarrbfs;": "&#10528;", 
    # north west and south east arrow: "&#10529;",   
    # north east and south west arrow: "&#10530;",
    "&nwarhk;": "&#10531;",
    "&nearhk;": "&#10532;",
    "&searhk;": "&#10533;",
    "&hksearow;": "&#10533;",
    "&swarhk;": "&#10534;",
    "&hkswarow;": "&#10534;",
    "&nwnear;": "&#10535;",
    "&nesear;": "&#10536;",
    "&toea;": "&#10536;",
    "&seswar;": "&#10537;",
    "&tosa;": "&#10537;",
    "&swnwar;": "&#10538;",
    # rising diagonal crossing falling diagonal: "&#10539;",
    # falling diagonal crossing rising diagonal: "&#10540;",
    # outh east arrow crossing north east arrow: "&#10541;",
    # north east arrow crossing south east arrow: "&#10542;",
    # falling diagonal crossing north east arrow: "&#10543;",
    # rising diagonal crossing south east arrow: "&#10544;",
    # north east arrow crossing north west arrow: "&#10545;",
    # north west arrow crossing north east arrow: "&#10546;",
    "&rarrc;": "&#10547;",
    # arrow pointing rightwards then curving upwards: "&#10548;",   
    "&cudarrr;": "&#10549;",
    "&ldca;": "&#10550;",
    "&rdca;": "&#10551;",
    "&cudarrl;": "&#10552;",
    "&larrpl;": "&#10553;",
    # top arc anticlockwise arrow: "&#10554;",    
    # bottom arc anticlockwise arrow: "&#10555;",    
    "&curarrm;": "&#10556;",
    "&cularrp;": "&#10557;",
    # 10558-10564: TODO
    "&rarrpl;": "&#10565;",
    # 10566-10567: TODO   
    "&harrcir;": "&#10568;",
    "&Uarrocir;": "&#10569;",
    "&lurdshar;": "&#10570;",
    "&ldrushar;": "&#10571;",
    # up barb right down barb left harpoon: "&#10572;",
    # up barb left down barb right harpoon: "&#10573;",  
    "&LeftRightVector;": "&#10574;",
    "&RightUpDownVector;": "&#10575;",
    "&DownLeftRightVector;": "&#10576;",
    "&LeftUpDownVector;": "&#10577;",
    "&LeftVectorBar;": "&#10578;",
    "&RightVectorBar;": "&#10579;",
    "&RightUpVectorBar;": "&#10580;",
    "&RightDownVectorBar;": "&#10581;",
    "&DownLeftVectorBar;": "&#10582;",
    "&DownRightVectorBar;": "&#10583;",
    "&LeftUpVectorBar;": "&#10584;",
    "&LeftDownVectorBar;": "&#10585;",
    "&LeftTeeVector;": "&#10586;",
    "&RightTeeVector;": "&#10587;",
    "&RightUpTeeVector;": "&#10588;",
    "&RightDownTeeVector;": "&#10589;",
    "&DownLeftTeeVector;": "&#10590;",
    "&DownRightTeeVector;": "&#10591;",
    "&LeftUpTeeVector;": "&#10592;",
    "&LeftDownTeeVector;": "&#10593;",
    "&lHar;": "&#10594;",
    "&uHar;": "&#10595;",
    "&rHar;": "&#10596;",
    "&dHar;": "&#10597;",
    "&luruhar;": "&#10598;",
    "&ldrdhar;": "&#10599;",
    "&ruluhar;": "&#10600;",
    "&rdldhar;": "&#10601;",
    "&lharul;": "&#10602;",
    "&llhard;": "&#10603;",
    "&rharul;": "&#10604;",
    "&lrhard;": "&#10605;",
    "&udhar;": "&#10606;",
    "&UpEquilibrium;": "&#10606;",
    "&duhar;": "&#10607;",
    "&ReverseUpEquilibrium;": "&#10607;",
    "&RoundImplies;": "&#10608;",
    "&erarr;": "&#10609;",
    "&simrarr;": "&#10610;",
    "&larrsim;": "&#10611;",
    "&rarrsim;": "&#10612;",
    "&rarrap;": "&#10613;",
    "&ltlarr;": "&#10614;",
    # leftwards arrow through less-than: "&#10615;",  
    "&gtrarr;": "&#10616;",
    "&subrarr;": "&#10617;",
    # subset above rightwards arrow: "&#10618;", 
    "&suplarr;": "&#10619;",
    "&lfisht;": "&#10620;",
    "&rfisht;": "&#10621;",
    "&ufisht;": "&#10622;",
    "&dfisht;": "&#10623;",
    # triple vertical bar delimiter: "&#10624;",   
    # z notation spot: "&#10625;",    
    # z notation type colon: "&#10626;",    
    # left white curly bracket: "&#10627;",    
    # right white curly bracket: "&#10628;",  
    "&lopar;": "&#10629;",
    "&ropar;": "&#10630;",
    # z notation left image bracket: "&#10631;",
    # z notation right image bracket: "&#10632;",
    # z notation left binding bracket: "&#10633;",
    # z notation right binding bracket: "&#10634;",
    "&lbrke;": "&#10635;",
    "&rbrke;": "&#10636;",
    "&lbrkslu;": "&#10637;",
    "&rbrksld;": "&#10638;",
    "&lbrksld;": "&#10639;",
    "&rbrkslu;": "&#10640;",
    "&langd;": "&#10641;",
    "&rangd;": "&#10642;",
    "&lparlt;": "&#10643;",
    "&rpargt;": "&#10644;",
    "&gtlPar;": "&#10645;",
    "&ltrPar;": "&#10646;",
    # left black tortoise shell bracket: "&#10647;",   
    # right black tortoise shell bracket: "&#10648;",    
    # dotted fence: "&#10649;",    
    "&vzigzag;": "&#10650;",
    # measured angle opening left: "&#10651;",
    "&vangrt;": "&#10652;",
    "&angrtvbd;": "&#10653;",   
    # angle with s inside: "&#10654;", 
    # acute angle: "&#10655;",     
    # spherical angle opening left: "&#10656;",     
    # spherical angle opening up: "&#10657;", 
    # turned angle: "&#10658;",     
    # reversed angle: "&#10659;",       
    "&ange;": "&#10660;",
    "&range;": "&#10661;",
    "&dwangle;": "&#10662;",
    "&uwangle;": "&#10663;",
    "&angmsdaa;": "&#10664;",
    "&angmsdab;": "&#10665;",
    "&angmsdac;": "&#10666;",
    "&angmsdad;": "&#10667;",
    "&angmsdae;": "&#10668;",
    "&angmsdaf;": "&#10669;",
    "&angmsdag;": "&#10670;",
    "&angmsdah;": "&#10671;",
    "&bemptyv;": "&#10672;",
    "&demptyv;": "&#10673;",
    "&cemptyv;": "&#10674;",
    "&raemptyv;": "&#10675;",
    "&laemptyv;": "&#10676;",
    "&ohbar;": "&#10677;",
    "&omid;": "&#10678;",
    "&opar;": "&#10679;",
    # circled reverse solidus: "&#10680;",  
    # circled perpendicular: "&#10681;",  
    # circle divided by horizontal bar and top half divided by vertical bar: "&#10682;",
    "&olcross;": "&#10683;",
    "&odsold;": "&#10684;",
    # up arrow through circle: "&#10685;",  
    "&olcir;": "&#10686;",
    "&ofcir;": "&#10687;",
    "&olt;": "&#10688;",
    "&ogt;": "&#10689;",
    "&cirscir;": "&#10690;",
    "&cirE;": "&#10691;",
    "&solb;": "&#10692;",
    "&bsolb;": "&#10693;",
    # squared asterisk: "&#10694;",      
    # squared small circle: "&#10695;",      
    # squared square: "&#10696;", 
    # &boxbox;": "&#10697;",
    # triangle with dot above": "&#10698;",    
    # triangle with underbar": "&#10699;",    
    # s in triangle: "&#10700;",        
    "&trisb;": "&#10701;",
    "&rtriltri;": "&#10702;",
    "&LeftTriangleBar;": "&#10703;",
    "&RightTriangleBar;": "&#10704;",
    # right wiggly fence: "&#10705;",      
    # bowtie with right half black: "&#10706;",      
    # black bowtie: "&#10707;", 
    # times with left half black: "&#10708;",
    # times with right half black: "&#10709;",    
    # white hourglass: "&#10710;", 
    # black hourglass: "&#10711;",        
    # left wiggly fence: "&#10712;",    
    # triangle with underbar": "&#10713;",    
    # s in triangle: "&#10714;",     
    # right double wiggly fence: "&#10715;",
    "&iinfin;": "&#10716;",
    "&infintie;": "&#10717;",
    "&nvinfin;": "&#10718;",
    # double-ended multimap: "&#10719;",
    # square with contoured outline: "&#10720;",
    # increases as: "&#10721;",     
    # shuffle product: "&#10722;",
    "&eparsl;": "&#10723;",
    "&smeparsl;": "&#10724;",
    "&eqvparsl;": "&#10725;",
    # gleich stark: "&#10726;",
    # thermodynamic: "&#10727;",
    # down-pointing triangle with left half black: "&#10728;",
    # down-pointing triangle with right half black: "&#10729;",
    # black diamond with down arrow: "&#10730;",
    "&lozf;": "&#10731;",
    "&blacklozenge;": "&#10731;",
    # 10732-10739: TODO    
    "&RuleDelayed;": "&#10740;",
    # reverse solidus operator: "&#10741;",
    "&dsol;": "&#10742;",
    # 10743-10751: TODO      
    "&xodot;": "&#10752;",
    "&bigodot;": "&#10752;",
    "&xoplus;": "&#10753;",
    "&bigoplus;": "&#10753;",
    "&xotime;": "&#10754;",
    "&bigotimes;": "&#10754;",
    # n-ary union operator with dot: "&#10755;",    
    "&xuplus;": "&#10756;",
    "&biguplus;": "&#10756;",
    #n-ary square intersection operator: "&#10757;",     
    "&xsqcup;": "&#10758;",
    "&bigsqcup;": "&#10758;",
    # 10759-10763: TODO    
    "&qint;": "&#10764;",
    "&iiiint;": "&#10764;",
    "&fpartint;": "&#10765;",
    # 10766-10767: TODO     
    "&cirfnint;": "&#10768;",
    "&awint;": "&#10769;",
    "&rppolint;": "&#10770;",
    "&scpolint;": "&#10771;",
    "&npolint;": "&#10772;",
    "&pointint;": "&#10773;",
    "&quatint;": "&#10774;",
    "&intlarhk;": "&#10775;",
    # 10776-10785: TODO    
    "&pluscir;": "&#10786;",
    "&plusacir;": "&#10787;",
    "&simplus;": "&#10788;",
    "&plusdu;": "&#10789;",
    "&plussim;": "&#10790;",
    "&plustwo;": "&#10791;",
    # plus sign with black triangle: "&#10792;",     
    "&mcomma;": "&#10793;",
    "&minusdu;": "&#10794;",
    # 10795-10796: TODO          
    "&loplus;": "&#10797;",
    "&roplus;": "&#10798;",
    "&Cross;": "&#10799;",
    "&timesd;": "&#10800;",
    "&timesbar;": "&#10801;",
    # semidirect product with bottom closed: "&#10802;",           
    "&smashp;": "&#10803;",
    "&lotimes;": "&#10804;",
    "&rotimes;": "&#10805;",
    "&otimesas;": "&#10806;",
    "&Otimes;": "&#10807;",
    "&odiv;": "&#10808;",
    "&triplus;": "&#10809;",
    "&triminus;": "&#10810;",
    "&tritime;": "&#10811;",
    "&iprod;": "&#10812;",
    "&intprod;": "&#10812;",
    # 10813-10814: TODO     
    "&amalg;": "&#10815;",
    "&capdot;": "&#10816;",
    # union with minus sign: "&#10817;",             
    "&ncup;": "&#10818;",
    "&ncap;": "&#10819;",
    "&capand;": "&#10820;",
    "&cupor;": "&#10821;",
    "&cupcap;": "&#10822;",
    "&capcup;": "&#10823;",
    "&cupbrcap;": "&#10824;",
    "&capbrcup;": "&#10825;",
    "&cupcup;": "&#10826;",
    "&capcap;": "&#10827;",
    "&ccups;": "&#10828;",
    "&ccaps;": "&#10829;",
    # double square intersection: "&#10830;",
    # double square union: "&#10831;",    
    "&ccupssm;": "&#10832;",  
    # logical and with dot above: "&#10833;",
    # logical or with dot above: "&#10834;",  
    "&And;": "&#10835;",
    "&Or;": "&#10836;",
    "&andand;": "&#10837;",
    "&oror;": "&#10838;",
    "&orslope;": "&#10839;",
    "&andslope;": "&#10840;",
    # logical or overlapping logical and: "&#10841;", 
    "&andv;": "&#10842;",
    "&orv;": "&#10843;",
    "&andd;": "&#10844;",
    "&ord;": "&#10845;",
    # logical and with double overbar: "&#10846;",
    "&wedbar;": "&#10847;",
    # logical and with double underbar: "&#10848;",
    # small vee with underbar: "&#10849;",    
    # logical or with double overbar: "&#10850;",        
    # logical or with double underbar: "&#10851;",
    # z notation domain antirestriction: "&#10852;",    
    # z notation range antirestriction: "&#10853;",        
    "&sdote;": "&#10854;",    
    # identical with dot above: "&#10855;",        
    # triple horizontal bar with double vertical stroke: "&#10856;",
    # triple horizontal bar with triple vertical stroke: "&#10857;",    
    # tilde operator with dot above: "&#10858;",
    # tilde operator with rising dots: "&#10859;",    
    # similar minus similar: "&#10860;",    
    "&congdot;": "&#10861;",
    "&easter;": "&#10862;",
    "&apacir;": "&#10863;",
    "&apE;": "&#10864;",
    "&eplus;": "&#10865;",
    "&pluse;": "&#10866;",
    "&Esim;": "&#10867;",
    "&Colone;": "&#10868;",
    "&Equal;": "&#10869;",
    # three consecutive equals signs: "&#10870;",    
    "&eDDot;": "&#10871;",
    "&ddotseq;": "&#10871;",
    "&equivDD;": "&#10872;",
    "&ltcir;": "&#10873;",
    "&gtcir;": "&#10874;",
    "&ltquest;": "&#10875;",
    "&gtquest;": "&#10876;",
    "&les;": "&#10877;",
    "&LessSlantEqual;": "&#10877;",
    "&leqslant;": "&#10877;",
    "&ges;": "&#10878;",
    "&GreaterSlantEqual;": "&#10878;",
    "&geqslant;": "&#10878;",
    "&lesdot;": "&#10879;",
    "&gesdot;": "&#10880;",
    "&lesdoto;": "&#10881;",
    "&gesdoto;": "&#10882;",
    "&lesdotor;": "&#10883;",
    "&gesdotol;": "&#10884;",
    "&lap;": "&#10885;",
    "&lessapprox;": "&#10885;",
    "&gap;": "&#10886;",
    "&gtrapprox;": "&#10886;",
    "&lne;": "&#10887;",
    "&lneq;": "&#10887;",
    "&gne;": "&#10888;",
    "&gneq;": "&#10888;",
    "&lnap;": "&#10889;",
    "&lnapprox;": "&#10889;",
    "&gnap;": "&#10890;",
    "&gnapprox;": "&#10890;",
    "&lEg;": "&#10891;",
    "&lesseqqgtr;": "&#10891;",
    "&gEl;": "&#10892;",
    "&gtreqqless;": "&#10892;",
    "&lsime;": "&#10893;",
    "&gsime;": "&#10894;",
    "&lsimg;": "&#10895;",
    "&gsiml;": "&#10896;",
    "&lgE;": "&#10897;",
    "&glE;": "&#10898;",
    "&lesges;": "&#10899;",
    "&gesles;": "&#10900;",
    "&els;": "&#10901;",
    "&eqslantless;": "&#10901;",
    "&egs;": "&#10902;",
    "&eqslantgtr;": "&#10902;",
    "&elsdot;": "&#10903;",
    "&egsdot;": "&#10904;",
    "&el;": "&#10905;",
    "&eg;": "&#10906;",
    # double-line slanted equal to or less-than: "&#10907;",    
    # double-line slanted equal to or greater-than: "&#10908;",     
    "&siml;": "&#10909;",
    "&simg;": "&#10910;",
    "&simlE;": "&#10911;",
    "&simgE;": "&#10912;",
    "&LessLess;": "&#10913;",
    "&GreaterGreater;": "&#10914;",
    # double nested less-than with underbar: "&#10915;",    
    "&glj;": "&#10916;",
    "&gla;": "&#10917;",
    "&ltcc;": "&#10918;",
    "&gtcc;": "&#10919;",
    "&lescc;": "&#10920;",
    "&gescc;": "&#10921;",
    "&smt;": "&#10922;",
    "&lat;": "&#10923;",
    "&smte;": "&#10924;",
    "&late;": "&#10925;",
    "&bumpE;": "&#10926;",
    "&pre;": "&#10927;",
    "&preceq;": "&#10927;",
    "&PrecedesEqual;": "&#10927;",
    "&sce;": "&#10928;",
    "&succeq;": "&#10928;",
    "&SucceedsEqual;": "&#10928;",
    # precedes above single-line not equal to: "&#10929;",
    # succeeds above single-line not equal to: "&#10930;",  
    "&prE;": "&#10931;",
    "&scE;": "&#10932;",
    "&prnE;": "&#10933;",
    "&precneqq;": "&#10933;",
    "&scnE;": "&#10934;",
    "&succneqq;": "&#10934;",
    "&prap;": "&#10935;",
    "&precapprox;": "&#10935;",
    "&scap;": "&#10936;",
    "&succapprox;": "&#10936;",
    "&prnap;": "&#10937;",
    "&precnapprox;": "&#10937;",
    "&scnap;": "&#10938;",
    "&succnapprox;": "&#10938;",
    "&Pr;": "&#10939;",
    "&Sc;": "&#10940;",
    "&subdot;": "&#10941;",
    "&supdot;": "&#10942;",
    "&subplus;": "&#10943;",
    "&supplus;": "&#10944;",
    "&submult;": "&#10945;",
    "&supmult;": "&#10946;",
    "&subedot;": "&#10947;",
    "&supedot;": "&#10948;",
    "&subE;": "&#10949;",
    "&subseteqq;": "&#10949;",
    "&supE;": "&#10950;",
    "&supseteqq;": "&#10950;",
    "&subsim;": "&#10951;",
    "&supsim;": "&#10952;",
    # subset of above almost equal to: "&#10953;",    
    # superset of above almost equal to: "&#10954;",   
    "&subnE;": "&#10955;",
    "&subsetneqq;": "&#10955;",
    "&supnE;": "&#10956;",
    "&supsetneqq;": "&#10956;",
    # square left open box operator: "&#10957;",
    # square right open box operator: "&#10958;",   
    "&csub;": "&#10959;",
    "&csup;": "&#10960;",
    "&csube;": "&#10961;",
    "&csupe;": "&#10962;",
    "&subsup;": "&#10963;",
    "&supsub;": "&#10964;",
    "&subsub;": "&#10965;",
    "&supsup;": "&#10966;",
    "&suphsub;": "&#10967;",
    "&supdsub;": "&#10968;",
    "&forkv;": "&#10969;",
    "&topfork;": "&#10970;",
    "&mlcp;": "&#10971;",
    # forking: "&#10972;",
    # nonforking: "&#10973;",
    # short left tack: "&#10974;",
    # short down tack: "&#10975;",
    # short up tack: "&#10976;",
    # perpendicular with s: "&#10977;",
    # vertical bar triple right turnstile: "&#10978;",
    # double vertical bar left turnstile: "&#10979;",    
    "&Dashv;": "&#10980;",
    "&DoubleLeftTee;": "&#10980;",
    # double vertical bar double left turnstile: "&#10981;", 
    "&Vdashl;": "&#10982;",
    "&Barv;": "&#10983;",
    "&vBar;": "&#10984;",
    "&vBarv;": "&#10985;",
    # double down tack: "&#10986;",    
    "&Vbar;": "&#10987;",
    "&Not;": "&#10988;",
    "&bNot;": "&#10989;",
    "&rnmid;": "&#10990;",
    "&cirmid;": "&#10991;",
    "&midcir;": "&#10992;",
    "&topcir;": "&#10993;",
    "&nhpar;": "&#10994;",
    "&parsim;": "&#10995;",
    # 10996-11004: TODO    
    "&parsl;": "&#11005;",
    # 11006-64255: TODO       
    "&fflig;": "&#64256;",
    "&filig;": "&#64257;",
    "&fllig;": "&#64258;",
    "&ffilig;": "&#64259;",
    "&ffllig;": "&#64260;",
    # 64261-119963: TODO     
    "&Ascr;": "&#119964;",
    "&Cscr;": "&#119966;",
    "&Dscr;": "&#119967;",
    # [not found]: "&#119968;",
    # [not found]: "&#119969;",
    # mathematical script capital g: "&#119970;",
    # [not found]: "&#119971;",
    # [not found]: "&#119972;", 
    "&Jscr;": "&#119973;",
    "&Kscr;": "&#119974;",
    # [not found]: "&#119975;",
    # [not found]: "&#119976;",    
    "&Nscr;": "&#119977;",
    "&Oscr;": "&#119978;",
    "&Pscr;": "&#119979;",
    "&Qscr;": "&#119980;",
    # [not found]: "&#119981;",    
    "&Sscr;": "&#119982;",
    "&Tscr;": "&#119983;",
    "&Uscr;": "&#119984;",
    "&Vscr;": "&#119985;",
    "&Wscr;": "&#119986;",
    "&Xscr;": "&#119987;",
    "&Yscr;": "&#119988;",
    "&Zscr;": "&#119989;",
    "&ascr;": "&#119990;",
    "&bscr;": "&#119991;",
    "&cscr;": "&#119992;",
    "&dscr;": "&#119993;",
    # [not found]: "&#119994;",
    "&fscr;": "&#119995;",
    # [not found]: "&#119996;",    
    "&hscr;": "&#119997;",
    "&iscr;": "&#119998;",
    "&jscr;": "&#119999;",
    "&kscr;": "&#120000;",
    "&lscr;": "&#120001;",
    "&mscr;": "&#120002;",
    "&nscr;": "&#120003;",
    # [not found]: "&#120004;",    
    "&pscr;": "&#120005;",
    "&qscr;": "&#120006;",
    "&rscr;": "&#120007;",
    "&sscr;": "&#120008;",
    "&tscr;": "&#120009;",
    "&uscr;": "&#120010;",
    "&vscr;": "&#120011;",
    "&wscr;": "&#120012;",
    "&xscr;": "&#120013;",
    "&yscr;": "&#120014;",
    "&zscr;": "&#120015;",
    # 120016-120067: TODO 
    "&Afr;": "&#120068;",
    "&Bfr;": "&#120069;",
    # [not found]: "&#120070;",
    "&Dfr;": "&#120071;",
    "&Efr;": "&#120072;",
    "&Ffr;": "&#120073;",
    "&Gfr;": "&#120074;",
    # [not found]: "&#120075;",
    # [not found]: "&#120076;",
    "&Jfr;": "&#120077;",
    "&Kfr;": "&#120078;",
    "&Lfr;": "&#120079;",
    "&Mfr;": "&#120080;",
    "&Nfr;": "&#120081;",
    "&Ofr;": "&#120082;",
    "&Pfr;": "&#120083;",
    "&Qfr;": "&#120084;",
    # [not found]: "&#120085;",
    "&Sfr;": "&#120086;",
    "&Tfr;": "&#120087;",
    "&Ufr;": "&#120088;",
    "&Vfr;": "&#120089;",
    "&Wfr;": "&#120090;",
    "&Xfr;": "&#120091;",
    "&Yfr;": "&#120092;",
    # [not found]: "&#120093;",
    "&afr;": "&#120094;",
    "&bfr;": "&#120095;",
    "&cfr;": "&#120096;",
    "&dfr;": "&#120097;",
    "&efr;": "&#120098;",
    "&ffr;": "&#120099;",
    "&gfr;": "&#120100;",
    "&hfr;": "&#120101;",
    "&ifr;": "&#120102;",
    "&jfr;": "&#120103;",
    "&kfr;": "&#120104;",
    "&lfr;": "&#120105;",
    "&mfr;": "&#120106;",
    "&nfr;": "&#120107;",
    "&ofr;": "&#120108;",
    "&pfr;": "&#120109;",
    "&qfr;": "&#120110;",
    "&rfr;": "&#120111;",
    "&sfr;": "&#120112;",
    "&tfr;": "&#120113;",
    "&ufr;": "&#120114;",
    "&vfr;": "&#120115;",
    "&wfr;": "&#120116;",
    "&xfr;": "&#120117;",
    "&yfr;": "&#120118;",
    "&zfr;": "&#120119;",
    "&Aopf;": "&#120120;",
    "&Bopf;": "&#120121;",
    "&Copf;": "&#120122;",
    "&Dopf;": "&#120123;",
    "&Eopf;": "&#120124;",
    "&Fopf;": "&#120125;",
    "&Gopf;": "&#120126;",
    # [not found]: "&#120127;",
    "&Iopf;": "&#120128;",
    "&Jopf;": "&#120129;",
    "&Kopf;": "&#120130;",
    "&Lopf;": "&#120131;",
    "&Mopf;": "&#120132;",
    # [not found]: "&#120133;",    
    "&Oopf;": "&#120134;",
    # [not found]: "&#120135;",     
    # [not found]: "&#120136;",     
    # [not found]: "&#120137;",     
    "&Sopf;": "&#120138;",
    "&Topf;": "&#120139;",
    "&Uopf;": "&#120140;",
    "&Vopf;": "&#120141;",
    "&Wopf;": "&#120142;",
    "&Xopf;": "&#120143;",
    "&Yopf;": "&#120144;",
    "&Zopf;": "&#120145;",
    "&aopf;": "&#120146;",
    "&bopf;": "&#120147;",
    "&copf;": "&#120148;",
    "&dopf;": "&#120149;",
    "&eopf;": "&#120150;",
    "&fopf;": "&#120151;",
    "&gopf;": "&#120152;",
    "&hopf;": "&#120153;",
    "&iopf;": "&#120154;",
    "&jopf;": "&#120155;",
    "&kopf;": "&#120156;",
    "&lopf;": "&#120157;",
    "&mopf;": "&#120158;",
    "&nopf;": "&#120159;",
    "&oopf;": "&#120160;",
    "&popf;": "&#120161;",
    "&qopf;": "&#120162;",
    "&ropf;": "&#120163;",
    "&sopf;": "&#120164;",
    "&topf;": "&#120165;",
    "&uopf;": "&#120166;",
    "&vopf;": "&#120167;",
    "&wopf;": "&#120168;",
    "&xopf;": "&#120169;",
    "&yopf;": "&#120170;",
    "&zopf;": "&#120171;",	
}

# Report list to store logs of changes
report = []

def replace_html_entities(file_path):
    """
    Reads the file content, replaces HTML entities with their corresponding numbers,
    writes the modified content back to the file, and logs the changes.
    """
    with open(file_path, 'r', encoding='utf-8') as f:
        content = f.read()

    original_content = content  # Keep a copy to compare later
    changes_made = []  # Track changes for this file

    # Replace all HTML entities in the content
    for entity_name, entity_number in html_entities.items():
        if entity_name in content:
            content = content.replace(entity_name, entity_number)
            changes_made.append(f"Replaced '{entity_name}' with '{entity_number}'")

    # Write the modified content back to the file
    with open(file_path, 'w', encoding='utf-8') as f:
        f.write(content)

    # If any changes were made, log them
    if changes_made:
        report.append(f"Changes in {file_path}:")
        report.extend(changes_made)
        report.append("")  # Blank line for readability

def process_directory(directory):
    """
    Recursively processes all HTML files in the given directory and its subdirectories.
    """
    for root, _, files in os.walk(directory):
        for file in files:
            if file.endswith('.html') or file.endswith('.htm'):
                file_path = os.path.join(root, file)
                print(f"Processing file: {file_path}")
                replace_html_entities(file_path)

def save_report(report_path):
    """
    Saves the report to a log file.
    """
    with open(report_path, 'w', encoding='utf-8') as f:
        f.write("\n".join(report))

# Entry point of the script
if __name__ == "__main__":
    directory_to_process = "C:\\TEST"  # Change this path as needed. Use double backslashes as shown.
    report_path = "C:\\TEST\\rpt.txt"  # Report file path. Use double backslashes as shown.

    process_directory(directory_to_process)
    save_report(report_path)

    print("HTML entity replacement completed.")
    print(f"Report saved to: {report_path}.")
  